******************************************************************
**  Measuring Women's and Youths' Informal Work in Non-Urban    **
**             Settings: Evidence from El Salvador              **
**                                                              **
**                                                              **
**  Country: El Salvador	  Date:  September 2022           	**
**                                                              **
**  Program Name:  02_variables_creation.do		                **
**                                                              **
**  Input Data Sets:                                            **
**		"$raw\all_sections.dta"   	     	           	    	**
**  Output Data Set:                                            **
**		"$baseclean\master_data.dta"    	   	           	    **
**                                                              **
**  Description:                                                **
**      Create indexes and variables for analysis               **
**                                                              **
**  Number of HHs:  1008                                        **
**                                                              **
**  Household:   hhid  	    			  						**
**                                                              **
**  Program first written: September, 2022 (Steffanny Romero)  	**
**  Program last revised:  February, 2024      		            **
**                                                              **
******************************************************************

clear all
set more off

set seed 487361

******************************
** Open Data
******************************

	use "$raw\all_sections.dta" , clear
	
******************************
** Create relevant variables 
******************************

** Control variable
	gen control=qx_type==0

** Treatments arms
	tab qx_type, gen(qx_typed)
	rename qx_typed1  qx_typed0
	rename qx_typed2  qx_typed1
	rename qx_typed3  qx_typed2

**# LABOR VARIABLES #1
	
** Employment
	gen employment= (s4q4==1 | s4q6==1 | s4q8==1 | s4q8a==1 | (s4q10==1 & s4q13<=2) | (s4q11==1 & s4q13<=2) | (s4q15==1 & s4q19<=2) | (s4q16==1 & s4q19<=2)  | (s4q18==1 & s4q19<=2) ) if selected==1

	la var employment "Employed"

** Absent
	gen absent=(s4q22==1 & s4q24==1) if selected==1
	la var absent "Temporary absent for work (last week)"
** Unemployed
	gen unemployed=(s4q28==1 | s4q29==1) | (s4q32==1 & (s4q34==1 | s4q35==1)) & employment==0 & absent==0 if selected==1
	la var unemployed "Unemployed"

** Labor force participation	
	gen laborforce=(employment==1 | absent==1 | unemployed==1) if selected==1
	la var laborforce "Labor force participation"
	
**# Other labor variables #2

** Work

	gen work= (s4q4==1 | s4q6==1 | s4q8==1 | s4q8a==1 | s4q10==1  | s4q11==1 | s4q15==1  | s4q16==1 | s4q18==1)  if selected==1

	la var work "Working"

** Work adjusted
	
	gen adjusted_work=work
	replace adjusted_work=1 if s4q30_oth=="comprar el producto"
	replace adjusted_work=1 if s4q30_oth=="conseguir un carretón para la venta de minutas"
	replace adjusted_work=1 if s4q30_oth=="Iniciar un negocio de bisutería"
	replace adjusted_work=1 if s4q30_oth=="comenzó a trabajar ayer en el cultivo de camarón para otra persona"
	replace adjusted_work=1 if s4q30_oth=="hacer venta de fresco, empanadas o tostadas"
	replace adjusted_work=1 if s4q30_oth=="empezó a vender pupusas en su casa pero no funcionó"
	replace adjusted_work=1 if s4q30_oth=="intento vender comida y cervezas"
	replace adjusted_work=1 if s4q30_oth=="realizar ventas en su hogar"
	replace adjusted_work=1 if s4q30_oth=="intento hacer venta de típicos"
	replace adjusted_work=1 if s4q30_oth=="averiguaron de vender minutas, o montar un negocio"
	replace adjusted_work=1 if s4q30_oth=="poner rótulos de venta de huevos y granos basicos"
	replace adjusted_work=1 if s4q30_oth=="intentar coser shorts"
	replace adjusted_work=1 if s4q30_oth=="lo llaman para ir a trabajar"
	replace adjusted_work=1 if s4q30_oth=="intentado sembrar maiz"
	replace adjusted_work=1 if s4q30_oth=="Invertir un poco de dinero para vender gelatinas."
	replace adjusted_work=1 if s4q30_oth=="empezó a vender pasteles y otras cosas de comer"
	replace adjusted_work=1 if s4q30_oth=="ELABORAR TARJETAS PARA TODA OCASIÓN"
	replace adjusted_work=1 if s4q30_oth=="va a limpiar milpas ajenas"
	replace adjusted_work=1 if s4q30_oth=="vende fresco, pupusas"
	replace adjusted_work=1 if s4q30_oth=="lo contratan otras personas cuando lo buscan"
	replace adjusted_work=1 if s4q30_oth=="compro ropa"
	replace adjusted_work=1 if s4q30_oth=="vender plátanos"
	replace adjusted_work=1 if s4q30_oth=="Ventas"
	replace adjusted_work=1 if s4q30_oth=="poner alguna venta en su casa"
	replace adjusted_work=1 if s4q30_oth=="ahora ha iniciado con venta de ropa usada"
	replace adjusted_work=1 if s4q30_oth=="Algunas veces corta cabello"
	replace adjusted_work=1 if s4q30_oth=="intento vender tomates"
	replace adjusted_work=1 if s4q30_oth=="han visto catálogos de ropa"
	replace adjusted_work=1 if s4q30_oth=="ayudante de estructurero"
	replace adjusted_work=1 if s4q30_oth=="hacer pasteles para venta"
	replace adjusted_work=1 if s4q30_oth=="compra y venta de ganado"
	
	la var adjusted_work "Adjusted work"	


** Informality 

	gen informal_sector_employee=1 if (employment==1 | absent==1) & (s4q48a==4 | s4q48a==5 | s4q48a==9 | s4q49==2 | s4q50==2 | s4q51==3 | s4q51==4 | s4q53<=2) 
	replace informal_sector_employee=0 if informal_sector_employee==. & (employment==1 | absent==1)
	la var informal_sector_employee "Employment in the informal sector"


	gen informal_employment=1 if informal_sector_employee==1 | s4q56__5==2 & (employment==1 | absent==1)
	replace informal_employment=0 if informal_employment==. & (employment==1 | absent==1)
	la var informal_employment "Informal employment"

**# Household and Individual Characteristics #2

** Household size (# of members)	
	bys interview__key: egen hh_members=max(r_members__id)
	la var hh_members "Household size (N)"

** Dependency ratio = (number of children 0-14 and adults 65+ divided by number of household members in the working age population 15-64)
	
	** Number of dependent household members (children under 14 or elderly 65+)
	gen temp=s1q4<14 | s1q4>65
	bys interview__key: egen dependents=total(temp)
	drop temp
	la var dependents "Number of dependent household members"
	
	** Number of household members in the working age population 15-64
	gen temp=s1q4<=64 | s1q4>=15
	bys interview__key: egen work_population=total(temp)
	drop temp
	la var work_population "Number of household members in the working age population"
	
	gen dependency_ratio=dependents/work_population
	la var dependency_ratio "Dependency ratio"
	
** Area of residence
	gen area_residence=cond(area==2,0,1)
	la var area_residence "Households in rural area"

** House and WASH Index captures the type of dwelling, dwelling property, wall and roof materials, access to water and type of toilet (equal to 1 if connected to a sewerage system or to a septic tank) 

*Valor de 1 si la característica es valiosa

	gen improve_tenure=1 if s11q3==1 | s11q3==2 
	gen improve_light=1 if s11q18==1 | s11q18==5 |  s11q18==6
	gen improve_walls=1 if s11q10==1 
	gen improve_rooginh=1 if s11q11==1 | s11q11==2
	gen improve_flooring=1 if s11q12==1 | s11q12==2
	gen improve_water=1 if s11q29==1
	gen improve_toilet=1 if s11q39==1 | s11q39==2

	recode improve_* (.=0)
	label val improve_* noyes

	** generar índice a la Anderson
	swindex improve_tenure improve_light improve_walls improve_rooginh improve_flooring improve_water improve_toilet, generate(house_index) replace normby(control) 
	
	la var house_index "House and WASH index, std"

	
** Access to internet
	gen access_internet=cond(s2bq6==1,1,0) if selected==1
	la var access_internet "Access to Internet (Wi-Fi)"

	gen access_internet2=s2bq7==1 | s2bq7==2 | s2bq6==1
	la var access_internet2 "Access to internet (WiFi + Mobile data)"
	
	gen access_cellphone=s2bq4==1

** Read or write
	gen read_write=s2q4==1
	
** Easy labor module
	gen easy_labor=s4q74 
	sum easy_labor
	replace easy_labor=`r(mean)' if missing(easy_labor)
	
	la var read_write "Read and write"
	la var access_cellphone "Access to mobile phone"

**	Gender 
	gen female=(s1q2==2)
	la var female "Female"

** Age dummy and indicator for age brackects -> hacerlos para ver la distribución 
	sum s1q4
	gen age=s1q4
	la var age "Age (years)"
	gen youth=(s1q4<=24 & s1q4>=15) if selected==1
	la var youth "Youth (%,15-24)"
	
	gen age1=(s1q4<=24 & s1q4>=15) if selected==1
	gen age2=(s1q4<=34 & s1q4>=25) if selected==1
	gen age3=(s1q4<=44 & s1q4>=35) if selected==1
	gen age4=(s1q4<=54 & s1q4>=45) if selected==1
	gen age5=(s1q4<=64 & s1q4>=55) if selected==1

	la var age1 "15-24 years"
	la var age2 "25-34 years"
	la var age3 "35-44 years"
	la var age4 "45-54 years"
	la var age5 "55-64 years"

** Marital status
	tab s1q7, gen(marital_status)
	gen married=s1q7==1 | s1q7==2
	la  var married "Married (1 if married or non-formal union, 0 otherwise)"
	
	gen never_married=s1q7==6
	la var never_married "Never married"
	
** Is the spouse/partner living in the household?
	gen living_partner=s1q8
	recode living_partner(2=0)	
	la var living_partner "Is the spouse/partner living in the household"

** Education
	gen education=s2q7a
	replace education=99 if education==. & s2q5==2
	replace education=98 if education==. & selected==1
	
	** recode Other (Specify)
	tab s2q7a_oth
	replace education=99 if inlist(s2q7a_oth,"NINGUNA", "NINGUNO", "Ninguno aprobó", "No obtuvo ningún título", "No termino ningun grado", "ninguno", "ninguna")
	replace education=99 if inlist(s2q7a_oth,"solo estudio primer grado y no lo termino", "solo fue una semana a la escuela", "ningún grado fue completado", "no termino ningun grado", "Ninguna", "Ninguno")
	
	replace education=99 if inlist(s2q7a_oth,"Solo inicio el primer grado 6 meses nada más", "no aprobó  ninguno", "si fue pero ninguno aprobó")
	
	replace education=98 if inlist(s2q7a_oth, "la informante principal no sabe", "no sabe", "no sabe la informante principal", "No sabe", "no está seguro", "no sabe hasta qué grado estudio")
	
	
	replace education=6 if inlist(s2q7a_oth, "High School Segundo Año", "Highschool 12th")
	
	replace education=3 if s2q7a_oth=="casa hogar para parálisis y personas con diferentes condiciones especiales ahí recibía educación especial"
	
	
	label define edu 1 "Early child education" 2 "Preschool" 3 "Special education" 4 "Primary" 5 "Secondary" 6 "Regular high school" 7 "Technical high school" 8 "Technical non-university" 9 "Bachelor's degree" 10 "Master's degree" 11 "PhD degree" 96 "Other (Specify)" 99 "No education" 98 "Don't know", replace
	label val education edu
	tab education, gen(edu)
	
	gen high_school=inlist(s2q7a,6,7,8,9) if selected==1
	la var high_school "High school or higher education"

** Income: continuous variable of assets index
	label define noyes 0 "NO" 1 "YES"  , replace

	forvalues i= 1(1)20 {
		recode s14q2__`i'(2=0)
		tab s14q2__`i' control
		lab val s14q2__`i' noyes
	}

	swindex s14q2__1 s14q2__2 s14q2__3 s14q2__4 s14q2__5 s14q2__6 s14q2__7 s14q2__8 s14q2__9  s14q2__11 s14q2__12 s14q2__13 s14q2__14 s14q2__15 s14q2__17 s14q2__18 s14q2__19 s14q2__20, generate(assets_index) replace normby(control) // -> quitar 10 y 16 
	la var assets_index "Assets index, std"

	sum assets_index, d
	gen high_income=assets_index>`r(p50)' if assets_index!=.
	la var high_income "Households with assets index above the median"
	
** Food insecurity: continuous variable of FIES 

	*merge m:1 interview__key using "$raw\fies dummy.dta", nogen

	*lab var food_insecure "Moderate to severe food insecurity"
	
** International Remittances received by the HH	
	
	gen foreign_remittance=s6q2__102
	recode foreign_remittance(2=0)
	la var foreign_remittance "Remittances received"
	
	gen foreign_remittance_amount=s6q3__102
	replace foreign_remittance_amount=. if foreign_remittance_amount==-9996
	la var foreign_remittance_amount "International Remittances received by the HH - Amount"

** HH has an NFE

	*merge m:1 interview__key using "$raw\nfe.dta", nogen
	*gen nfe_operating_d=nfe_operating>0 if nfe_operating!=.
	*la var nfe_operating_d "At least one of the household NFE is operating"
	
	gen nfe=s5b_e1==1 if s5b_e1!=.
	la var nfe "Households has a non-farm enterprise"
	
** If the HH has agriculture activities=1
	
	gen agriculture_act=s12cq1==1 | s12cq5==1 | s12cq8==1 if s12C_respondent!=.
	la var agriculture "Households engages in agricultural activities"

	
** Presence of mother/mother-in-law=dummy variable in HH

	gen temp=(s1q3==6 | s1q3==11) & female==1
	bys interview__key: egen presence_mother=max(temp)
	drop temp

	la var presence_mother "Presence of mother/mother-in-law"

** Risk aversion

** Ivette defition

	recode s9q1-s9q10 (2=0)
	replace s9q1=. if s9q2==.
	
	gen expectedloss1=2*s9q1
	gen expectedloss2=1.50*s9q2
	gen expectedloss3=1.25*s9q3
	gen expectedloss4=1*s9q4
	gen expectedloss5=0.75*s9q5
	gen expectedloss6=0.50*s9q6
	
	egen expectedloss=rowtotal(expectedloss*)
	replace expectedloss=. if s9q1==.
	gen risk_aversion=expectedloss/7
	
	la var risk_aversion "Risk aversion index" // 1= high risk aversion
	
		**Opción 1: pago seguro
		**Opción 2: jugar lotería

	recode s9q1-s9q10 (0=2)

	*De la 1 a 6 escogieron pago seguro siempre - > aversos al riesgo
	gen risk=1 if s9q1==1 & s9q2==1 & s9q3==1 & s9q4==1 & s9q5==1 & s9q6==1
	
	*De la 8 a 10 escogieron loteria siempre -> risk loving
	replace risk=2 if s9q8==2 & s9q9==2 & s9q10==2
	
	*Todos los demás neutrales
	replace risk=0 if risk==. & s9q11!=.
	
	# delimit;
	label define risk
	 0 "Risk Neutral" 
	 1 "Risk Averse" 
	 2 "Risk Lovers", replace;
    # delimit cr
	la val risk risk

	la var risk "Risk Category"
	tab risk, gen (risk)

	*Cambiar pago seguro como 0 y loteria 1 -> sumar cuántas veces escogió la loteria
	
 	forvalues i= 1(1)10 {
		replace s9q`i'=s9q`i'-1
	}

	//labeling
	local Y `" "Option A: Sure payment $0" "Option A: Sure payment $0.50" "Option A: Sure payment $0.75" "Option A: Sure payment $1.00" "Option A: Sure payment $1.25" "Option A: Sure payment $1.50" "Option A: Sure payment $2.00" "Option A: Sure payment $2.50" "Option A: Sure payment $3.00" "Option A: Sure payment $3.50" "'

	local x = 1 
	foreach y of local Y {
		label define options`x' 0 "`y'" 1 "Option B: Lottery $4 with probability 50% or $0 with probability 50%" , replace
		la val s9q`x' options`x'
		local ++ x
	}

	egen rounds_lottery=rowtotal(s9q1 s9q2 s9q3 s9q4 s9q5 s9q6 s9q7 s9q8 s9q9 s9q10), missing
	la var rounds_lottery "Number of rounds played lottery"
	
	
	*Valor ponderado de la loteria:  crearla 
		*sumatoria de la utilidad* dummy de si escogió loteria 
		*** (Valor esperado - pago seguro)*dummy_loteria_ronda
		**** sumar a nivel de individuo
		
	gen utility1=(2 - 0)*s9q1	
	gen utility2=(2 - 0.5)*s9q2	
	gen utility3=(2 - 0.75)*s9q3	
	gen utility4=(2 - 1)*s9q4	
	gen utility5=(2 - 1.25)*s9q5	
	gen utility6=(2 - 1.5)*s9q6	
	gen utility7=(2 - 2)*s9q7	
	gen utility8=(2 - 2.5)*s9q8	
	gen utility9=(2 - 3)*s9q9	
	gen utility10=(2 - 3.5)*s9q10	
	
	egen utility=rowtotal(utility1 utility2 utility3 utility4 utility5 utility6 utility7 utility8 utility9 utility10), missing
	la var utility "Lottery Weighted Value"

	
** Barriers to entering the labor market	-> revisar luego (revisar en excel)
	tab1 s4q75__*
	tab1 s5aq10__*

** Lack of skills needed for available jobs	(dummy - recode)
	tab1 s4aq18__*
	
	recode s4aq18__* (2=0)
	label val s4aq18__* noyes

** Aspirations	(dummy- recode)
	tab1 s5eq22a s5eq24aa s5eq36   
	recode s5eq22a (2=0)
	recode s5eq24aa (2=0)
	recode s5eq36 (2=0)
	label val s5eq22a noyes
	label val s5eq24aa noyes
	label val s5eq36 noyes

*--- education gap (diferencia s5eq22 - education)	

	** Recode other specify:
	replace s5eq22=98 if inlist(s5eq22_os, "no sabe", "no sabe respondió", "no se respondió el", "pero no tiene definido el nivel", "aprender a leer")
	replace s5eq22=6 if inlist(s5eq22_os,"BACHILLERATO GENERAL" ,"Bachillerato General" ,"bachillerato general","Bachillerato, sin especificar opción por el encuestado")
	replace s5eq22=7 if inlist(s5eq22_os,"BACHILLERATO TÉCNICO","Bachillerato Técnico")
	replace s5eq22=5 if s5eq22_os=="Secundaria Octavo grado"
	replace s5eq22=4 if s5eq22_os=="Tercer grado"
	replace s5eq22=8 if inlist(s5eq22_os,"Estudiar Idiomas", "estudiar idiomas", "Bilingüe en idiomas",  "aprender ingles", "completar el inglés y prender otro idioma", "curso de inglés", "enfermeria" , "ingles", "inglés")	
	replace s5eq22=9 if inlist(s5eq22_os,"otra carrera universitaria","ingeniería")
		
	label val s5eq22 edu

	** pasar dont know a missing y ponerlo en la condición
	** recode no education=0
	
	recode s5eq22(99=0)
	recode education(99=0)
	
	recode s5eq22(98=.)
	recode education(98=.)
	
	gen edu_gap=1 if s5eq22==education & s5eq22!=. & education!=.
	replace edu_gap=2 if s5eq22>education & s5eq22!=. & education!=.
	replace edu_gap=3 if s5eq22<education & s5eq22!=. & education!=.
	
	recode s5eq22(0=99)
	recode education(0=99)
	
	recode s5eq22(.=98)
	recode education(.=98)

	tab edu_gap, gen(edu_gap)
	la var edu_gap1 "Has the dream education"
	la var edu_gap2 "Has less education than dream education"
	la var edu_gap3 "Has more education than dream education"
	la var edu_gap "Education gap"
	
*---- Dream job STEM (11-14-31)
	gen dream_job_stem=s5eq24b==11 | s5eq24b==14 | s5eq24b==31 if s5eq24b!=.
	la var dream_job_stem "Dream job STEM"
	
** Patrichal social norms (index)
 
 	* DUMMY: s7q1=<2, s7q3>=2, s7q8==2, s7q10==2, s7q11==1, s7q12==2, s7q14==2, s7q17==2, s7q19>=4 

	gen s7q1_d=s7q1<=2 if s7q1!=.
	gen s7q3_d=s7q3>=2 if s7q3!=.
	gen s7q8_d=s7q8==2 if s7q8!=.
	gen s7q10_d=s7q10==2 if s7q10!=.
	gen s7q11_d=s7q11==1 if s7q11!=.
	gen s7q12_d=s7q12==2 if s7q12!=.
	gen s7q14_d=s7q14==2 if s7q14!=.
	gen s7q17_d=s7q17==2 if s7q17!=.
	gen s7q19_d=s7q19>=4 if s7q19!=.

	** generar índice a la Anderson
	swindex s7q1_d s7q3_d s7q8_d s7q10_d s7q11_d s7q12_d s7q14_d s7q17_d s7q19_d, generate(socialnorms_index) replace normby(control) 
	
	la var socialnorms_index "Patrichal social norms index, std"

  
** Domestic obligations	Number of hours devoted to household/care activities (time use module: codes 23, 24, 25, 27, 28)


*--- Domestic obligations: en actividad principal o secundaria hace cuidados del hogar 

	forvalues i= 4(1)27 {

	gen s6cq`i'_d=(s6cq`i' ==2 & inlist(s6cq`i'b,23,24,25,26,27,28)) | (s6cq`i'd==2 & inlist(s6cq`i'e,23,24,25,26,27,28))
	}
	egen domestic_hours=rowtotal(s6cq4_d - s6cq27_d) if s6q0!=.
	
	la var domestic_hours "Domestic obligations (Number of hours)"

*--- Domestic obligations: estricto - solo actividad principal en cuidado del hogar --> que no hacía no nada más (incluyo si como segunda actividad también hacía obligaciones domésticas)

	forvalues i= 4(1)27 {

	gen s6cq`i'_d2=(s6cq`i'==2 & inlist(s6cq`i'b,23,24,25,26,27,28)) & (s6cq`i'c==1 | (s6cq`i'd==2 & inlist(s6cq`i'e,23,24,25,26,27,28)))
	}
	egen domestic_hours2=rowtotal(s6cq4_d2 - s6cq27_d2) if s6q0!=.

	la var domestic_hours2 "Only domestic obligations (Number of hours)"


*--- Productive activities: en actividad principal o secundaria se dedica a actividades productivas 

	forvalues i= 4(1)27 {

	gen s6cq`i'_act=(s6cq`i' ==3) | (s6cq`i'd==3)
	}
	egen productive_hours=rowtotal(s6cq4_act - s6cq27_act) if s6q0!=.
	
	la var productive_hours "Productive activities (Number of hours)"

*--- Productive activities: estricto - solo actividad principal en actividades productivas --> que no hacía no nada más (incluyo si como segunda actividad también hacía actividades productivas)

	forvalues i= 4(1)27 {

	gen s6cq`i'_act2=(s6cq`i'==3) & (s6cq`i'c==1 | (s6cq`i'd==3))
	}
	egen productive_hours2=rowtotal(s6cq4_act2 - s6cq27_act2) if s6q0!=.

	la var productive_hours2 "Only productive activities  (Number of hours)"
	
** Social Desirability index	
	
	* Reversing the negatively keyed items (5,9,11,12,14)
	
 	foreach i in 5 9 11 12 14 {
		gen s12q`i'_rev=s12q`i'
		replace s12q`i'_rev=5 if s12q`i'==1
		replace s12q`i'_rev=4 if s12q`i'==2
		replace s12q`i'_rev=3 if s12q`i'==3
		replace s12q`i'_rev=2 if s12q`i'==4
		replace s12q`i'_rev=1 if s12q`i'==5
		}
	
	egen social_desirability=rowtotal(s12q1 s12q2 s12q3 s12q4 s12q5_rev s12q6 s12q7 s12q8 s12q9_rev s12q10 s12q11_rev  s12q12_rev s12q13 s12q14_rev s12q15 s12q16) // fuera del rango
	
	swindex s12q1 s12q2 s12q3 s12q4 s12q5_rev s12q6 s12q7 s12q8 s12q9_rev s12q10 s12q11_rev s12q12_rev s12q13 s12q14_rev s12q15 s12q16, generate(socialdesir_index) replace normby(control) 
	
	la var socialdesir_index "Social Desirability index, std"

	

** Number of eligible HH members	
	bys interview__key: egen hh_elegible=total(selected)
	la var hh_elegible "Number of eligible members"

** Self-respondent in labor module"
 gen self_respondent=s4q2==1 if selected==1	
 la var self_respondent "Self-respondent in labor module"	
 
** Someone else int he HH was working?
	bys hhid:  egen workers_hh=total(work)
	gen else_worker=workers_hh>0 if work!=.
	replace else_worker=else_worker-work if workers_hh==1
 	la var else_worker "Someone else in the HH was working"
	la var workers_hh "Number of members who were working"
	
** Own children (Not ready yet)
/*
	bys hhid: egen temp_mother=max(s1q13) if 
	bys hhid: egen temp_father=max(s1q11)

	gen own_children=1 if temp_father==r_members__id
	replace own_children=1 if temp_mother==r_members__id
	replace own_children=0 if own_children==. & selected==1
	drop temp_father temp_mother
*/

	preserve
	keep if s1q4<18
	drop if  s1q11==.
	keep hhid s1q11
	rename s1q11 r_members__id
	gen seq=1
	collapse (mean) seq , by(hhid r_members__id)
	drop seq
	tempfile fathers
	save `fathers' , replace
	restore

	preserve
	keep if s1q4<18
	drop if  s1q13==.
	keep hhid s1q13
	rename s1q13 r_members__id
	gen seq=1
	collapse (mean) seq , by(hhid r_members__id)
	drop seq
	tempfile mothers
	save `mothers' , replace
	restore

	merge 1:1 hhid r_members__id using `fathers' , gen(own_father)
	merge 1:1 hhid r_members__id using `mothers' , gen(own_mother)
	gen own_children=own_father==3 | own_mother==3
	drop own_father own_mother
	
** Elderly in the household
	bys hhid: egen temp_elderly=max(s1q4)
	gen elderly_hh=temp_elderly>64
	drop temp_elderly
	la var elderly_hh "Elderly in the household"

** Childcare center in the community
	gen childcare_center=s7q16==1 if s7q16!=.
	la var childcare_center "Childcare center in the community"

	tempfile master_data 
	save `master_data'

** construct variables for proxy analysis
	
	gen proxy=1-self_respondent if qx_type!=2
	*gen t1_proxy=qx_type*proxy

	// sex of proxy respondent
	preserve
	drop if s4q2a==.
	duplicates drop interview__key s4q2a, force
	keep interview__key s4q2a 
	rename s4q2a r_members__id 

	merge 1:1 interview__key r_members__id using `master_data', keepusing(female high_school s1q3 education) keep(3) nogen
	ren r_members__id s4q2a
	rename female proxyfemale
	rename high_school proxyhigh_school
	rename s1q3 proxyrelation
	replace proxyhigh_school=0 if education==98
	drop education
	tempfile proxy 
	save `proxy'
	restore

	drop _merge
	merge m:1 interview__key s4q2a using `proxy', nogen


	replace proxy=0 if proxyfemale==. & proxy==1
	gen proxyspouse= (s1q3==1 & proxyrelation==2) | (s1q3==2 & proxyrelation==1) if proxy==1

	gen proxyhead=proxyrelation==1 if proxy==1

	la var proxyspouse "Proxy is spouse"
	la var proxyhead "Proxy is head"
	la var proxyfemale "Proxy is woman"
	la var proxyhigh_school "Proxy has high school or more"
	*la var proxyrelation "Proxy relationship with the head of the household"
	la var proxy "Proxy"	

	// keep only the selected members	
	keep if selected==1
	
	// Social desirability in the EA. 
bys ea_code: egen socialdesir_all=mean(socialdesir_index)

** Generate interactions variables

	gen treat1=qx_type==1 if qx_type!=.
	gen treat2=qx_type==2 if qx_type!=.

// Female 	
	gen treat1_female=qx_typed1*female
	gen treat2_female=qx_typed2*female

// Youth
	gen treat1_youth=qx_typed1*youth
	gen treat2_youth=qx_typed2*youth

// Average number of Average time spent on housework (women) 

* promedio de mujeres
	bys ea_code: egen totval=total(domestic_hours2) if female==1
	bys ea_code: egen cval=count(domestic_hours2) if female==1
	gen domestic_female=(totval - domestic_hours2) / (cval - 1)

	bys ea_code: egen temp=mean(domestic_hours2) if female==1
	bys ea_code: ereplace domestic_female=max(temp) if domestic_female==.
	drop totval cval temp

* create interactions
	gen domestic_female_sex=domestic_female*female

	gen treat1_domestic_female=qx_typed1*domestic_female
	gen treat2_domestic_female=qx_typed2*domestic_female

	gen treat1_domestic_female_sex= qx_typed1*domestic_female*female
	gen treat2_domestic_female_sex= qx_typed2*domestic_female*female

	la var domestic_female "Average time spent on housework (women)"
	la var domestic_female_sex "Average time spent on housework (women) x Female"
	
	la var treat1_domestic_female "LOA x Average time spent on housework (women)"
	la var treat2_domestic_female "ESR x Average time spent on housework (women)"
	
	la var treat1_domestic_female_sex "LOA x Average time spent on housework (women) x Female"
	la var treat2_domestic_female_sex "ESR x Average time spent on housework (women) x Female"

// Employment in the informal sector in the EA. (women,men,all, young men)


* promedio de todos
	bys ea_code: egen totval=total(informal_sector_employee)
	bys ea_code: egen cval=count(informal_sector_employee) 
	gen informal_sector_share=(totval - informal_sector_employee) / (cval - 1)

	bys ea_code: egen temp=mean(informal_sector_employee)
	bys ea_code: ereplace informal_sector_share=max(temp) if informal_sector_share==.

* estandarizar
	egen informal_sector_share_std=std(informal_sector_share)
	drop totval cval temp

* promedio de mujeres
	bys ea_code: egen totval=total(informal_sector_employee) if female==1
	bys ea_code: egen cval=count(informal_sector_employee) if female==1
	gen informal_sector_female=(totval - informal_sector_employee) / (cval - 1)

	bys ea_code: egen temp=mean(informal_sector_employee) if female==1
	bys ea_code: ereplace informal_sector_female=max(temp) if informal_sector_female==.

* estandarizar
	egen informal_female_std=std(informal_sector_female)
	drop totval cval temp

* para todos los hombres
	bys ea_code: egen totval=total(informal_sector_employee) if female==0 
	bys ea_code: egen cval=count(informal_sector_employee) if female==0 
	gen informal_sector_male=(totval - informal_sector_employee) / (cval - 1)

	bys ea_code: egen temp=mean(informal_sector_employee) if female==0
	bys ea_code: ereplace informal_sector_male=max(temp) if informal_sector_male==.

* estandarizar
	egen informal_male_std=std(informal_sector_male)
	drop totval cval temp

** hombres jovenes
	bys ea_code: egen totval=total(informal_sector_employee) if female==0 & youth==1
	bys ea_code: egen cval=count(informal_sector_employee) if female==0 & youth==1
	gen informal_maleyouth=(totval - informal_sector_employee) / (cval - 1)

	bys ea_code: egen temp=mean(informal_sector_employee) if female==0 & youth==1
	bys ea_code: egen temp2=max(temp) 
	bys ea_code: replace informal_maleyouth=temp2 if informal_maleyouth==.
	replace informal_maleyouth=0 if informal_maleyouth==.

* estandarizar
	egen informal_maleyouth_std=std(informal_maleyouth)
	drop totval cval temp temp2
	
** Create interactions 

	gen treat1_informal_sector_share=qx_typed1*informal_sector_share_std
	gen treat2_informal_sector_share=qx_typed2*informal_sector_share_std

	gen treat1_informal_female_std=qx_typed1*informal_female_std
	gen treat2_informal_female_std=qx_typed2*informal_female_std
	
	gen treat1_informal_maleyouth_std=qx_typed1*informal_maleyouth_std
	gen treat2_informal_maleyouth_std=qx_typed2*informal_maleyouth_std

	gen treat1_informal_male_std=qx_typed1*informal_male_std
	gen treat2_informal_male_std=qx_typed2*informal_male_std

	*all
	gen informal_sex=informal_sector_share_std*female
	gen  treat1_informal_sex= qx_typed1*informal_sector_share_std*female
	gen  treat2_informal_sex= qx_typed2*informal_sector_share_std*female
	
	*mujeres
	gen informalfemale_sex=informal_female_std*female
	gen  treat1_informalfemale_sex= qx_typed1*informal_female_std*female
	gen  treat2_informalfemale_sex= qx_typed2*informal_female_std*female
	
	*hombres
	gen informalmale_sex=informal_male_std*female
	gen  treat1_informalmale_sex= qx_typed1*informal_male_std*female
	gen  treat2_informalmale_sex= qx_typed2*informal_male_std*female

	*para la de jovenes
	gen informal_youth=informal_male_std*youth
	gen  treat1_informal_youth= qx_typed1*informal_male_std*youth
	gen  treat2_informal_youth= qx_typed2*informal_male_std*youth

** compare sectors 
// perdemos algunas observaciones de los que no respondieron , sample=1530
	gen act_agri=s4q41CAT==1 if s4q41CAT!=.
	gen act_manuf=s4q41CAT==3 if s4q41CAT!=.
	gen act_comm=s4q41CAT==7 if s4q41CAT!=.
	gen act_servi=inlist(s4q41CAT,4, 5, 6,8, 9, 10,11,12,13,14,15,16,17,18,19,20) if s4q41CAT!=. // todos los que no esten en los 3 primeros
	gen agrivsnowork=.
	replace agrivsnowork=1 if act_agri==1
	replace agrivsnowork=0 if work==0

	***
	gen agrivsmanuf=.
	replace agrivsmanuf=1 if act_agri==1
	replace agrivsmanuf=0 if act_manuf==1

	gen agrivscomm=.
	replace agrivscomm=1 if act_agri==1
	replace agrivscomm=0 if act_comm==1

	gen agrivservi=.
	replace agrivservi=1 if act_agri==1
	replace agrivservi=0 if act_servi==1

*** for placebo:

	gen formalemployee=1-informal_sector_employee
	replace formalemployee=0 if formalemployee==.
	
	lab var formalemployee "Employed in the formal sector"
** Labeling
	la var youth "Youth"
	la var female "Female"
	
	la var qx_type "Survey type"
	la var qx_typed0 "Control"
	la var qx_typed1 "LOA"
	la var qx_typed2 "ESR"

	la var work "Working"
	la var employment "Employed"
	
	la var treat1_female "LOA x Female"
	la var treat1_youth  "LOA x Youth"

	
	la var treat2_female "ESR x Female"
	la var treat2_youth  "ESR x Youth"
	

	la var treat1_domestic_female "LOA x Average time spent on housework (women)"
	la var treat2_domestic_female "ESR x Average time spent on housework (women)"
	la var domestic_female "Average time spent on housework (women)"
		
	la var treat1_informal_sector_share  "LOA x Informal employment in the EA"
	la var treat2_informal_sector_share "ESR x Informal employment in the EA"
	la var informal_sector_share_std "Informal employment in the EA"
	
	la var informal_sector_female "Informal employment in the EA (share of women)"  
	la var informal_sector_male "Informal employment in the EA (share of men)"

	la var treat1_informal_female_std  "LOA x Informal employment in the EA"
	la var treat2_informal_female_std"ESR x Informal employment in the EA"
	la var informal_female_std "Informal employment in the EA"

	la var treat1_informal_male_std  "LOA x Informal employment in the EA"
	la var treat2_informal_male_std"ESR x Informal employment in the EA"
	la var informal_male_std "Informal employment in the EA"

	la var treat1_informal_maleyouth_std  "LOA x Informal employment in the EA"
	la var treat2_informal_maleyouth_std "ESR x Informal employment in the EA"
	la var informal_maleyouth_std "Informal employment in the EA"
	la var treat1_informal_sex "LOA x Informal employment in the EA x Female"
	la var treat2_informal_sex "ESR x Informal employment in the EA x Female" 
	la var informal_sex "Informal employment in the EA x Female"	

	la var informal_youth "Informal employment in the EA x Youth" 
	la var treat1_informal_youth "LOA x Informal employment in the EA x Youth" 
	la var treat2_informal_youth "ESR x Informal employment in the EA x Youth"
  
    lab var agrivsnowork "Agriculture versus No employment"
	lab var act_agri "Agriculture versus Other Sectors"
	lab var agrivservi "Agriculture versus Services"
	lab var agrivsmanuf "Agriculture versus Manufacture"
	lab var agrivscomm "Agriculture versus Commerce"

	
** LABEL VARIABLES
     numlabel, add	
	
** LABEL DATA 
     label data "El Salvador Labor - Master data"
	 
	sort interview__key r_members__id 
** SAVE INTERMEDIATE FILE
      compress
      saveold "$baseclean\master_data.dta", replace		 	 
	