******************************************************************
**  Measuring Women's and Youths' Informal Work in Non-Urban    **
**             Settings: Evidence from El Salvador              **
**                                                              **
**                                                              **
**  Country: El Salvador	  Date:  September 2022           	**
**                                                              **
**  Program Name:  03_ehpm.do	          					    **
**                                                              **
**  Input Data Sets:                                            **
**		"$raw\EHPM 2022.sav"    	   			           	    **
**                                                              **
**  Description:                                                **
**      Create dataset from EHPM to compare with our data       **
**                                                              **
**                                                              **
**  Program first written: September, 2022 (Steffanny Romero)  	**
**  Program last revised:  February, 2024      		            **
**                                                              **
******************************************************************
clear all
set more off

set seed 487361

/*
	To execute this code, you must first download the dataset "Encuesta de Hogares de Propósitos Multiples 2022" by following these instructions:

	1. Navigate to the public repository by visiting the following link in your web browser: [https://onec.bcr.gob.sv/Repositorio_archivos/]
	2. Fill in the required fields to register. Once completed, datasets available for download, along with their respective years, will appear on the right side of the webpage.
	3. Locate the "Encuesta de Hogares de Propósitos Multiples 2022" and click on the green download button next to its name.
	4. Extract the compressed/zipped folder and save the downloaded dataset in the "Raw data" folder within the replication package directory.
	5. Finally, run the code.
*/

* import base 

import spss using "$raw\EHPM 2022.sav", clear

* female
	gen female=1 if r104==2
	replace female=0 if r104==1

	la define female 0 "Male" 1 "Female", replace
	la value female female

	la var female "Female (%)"

* Age
	ren r106 age 
	la var age "Age (years)"
* Education
	gen high_school=r214>=3 & r214<8
	la var high_school "High school or further education (%)"
* Read or write
	gen read_write=r202a!=2
	la var read_write "Read or write (%)"

* Never married
	gen never_married=r107==6
	la var never_married "Never married (%)"
	
* Access to mobile phone
	gen access_cellphone=r3212a==1
	la var access_cellphone "Access to mobile phone (%)"

* Access to internet (Wi-Fi)
	gen access_internet=r3213a==1
	la var access_internet "Access to internet (Wi-Fi) (%)"

* Keep rural area & 15-64 yrs
	keep if area==0	
	keep if age>=15 & age<=64

	keep if r004==6 | r004==11
* Save dataset
	keep idboleta age female high_school read_write never_married access_cellphone access_internet miemh r103 r004 fac00 
	save "$intermed\EHPM 2022_restringida.dta", replace