******************************************************************
**  Measuring Women's and Youths' Informal Work in Non-Urban    **
**             Settings: Evidence from El Salvador              **
**                                                              **
**                                                              **
**  Country: El Salvador	  Date:  September 2022           	**
**                                                              **
**  Program Name:  03_main_tables_figures.do	                **
**                                                              **
**  Input Data Sets:                                            **
**		"$baseclean\master_data.dta"    	   	           	    **
**                                                              **
**  Description:                                                **
**      Create main tables and figures 				            **
**                                                              **
**  Number of HHs:  1008                                        **
**                                                              **
**  Household:   hhid  	    			  						**
**                                                              **
**  Program first written: September, 2022 (Steffanny Romero)  	**
**  Program last revised:  April, 2024      		            **
**                                                              **
******************************************************************
clear all
set more off

set seed 487361

// Import dataset

	use "$baseclean\master_data.dta", clear

**# Table 1: Descriptive Statistics of Household and Individual Characteristics and Table 2: Balance Tests #

	putexcel set "$tables\Table1.xlsx", replace sheet(PanelB, replace) 
	
	putexcel B1="Mean" C1="SD" D1="Min" E1="Max" F1="Observations"	

	local i = 2
	foreach x in female age high_school read_write never_married access_cellphone access_internet {
		local ytitle : var label `x'
		sum `x' if selected==1, d
		putexcel A`i'="`ytitle'" 
		putexcel B`i'= `r(mean)', nformat(number_d2)
		putexcel C`i'=`r(sd)', nformat(number_d2)
		putexcel D`i'=`r(min)'
		putexcel E`i'=`r(max)'
		putexcel F`i'=`r(N)'
		
		local i = `i' + 1					
		*sleep 10000
}
	*sleep 60000

	global X female age high_school read_write never_married access_cellphone access_internet 
	
	reghdfe treat1 $X if qx_type != 2, absorb(ea_code) cluster(hhid) 
	reghdfe treat2 $X if qx_type != 1, absorb(ea_code) cluster(hhid) 
	reghdfe treat2 $X if qx_type != 0, absorb(ea_code) cluster(hhid) 
	
	balancetable (mean if qx_type == 0) (mean if qx_type == 1) 	(mean if qx_type == 2) (diff treat1 if qx_type != 2)  (diff treat2 if qx_type != 1) (diff treat2 if qx_type != 0) $X if selected==1 using "$tables\Table2.xlsx", cov(i.ea_code) vce(cluster hhid) ctitles("Control" "LOA" "ESR" "LOA vs Control" "ESR vs Control"  "ESR vs LOA") wide(mean pval) pvalues  replace varla sheet(PanelB)
	*sleep 60000

	preserve
	keep if main==1 // una observación por hogar
	global X hh_members dependency_ratio area_residence high_income food_insecure foreign_remittance nfe agriculture
	reghdfe treat1 $X if qx_type != 2, absorb(ea_code) cluster(ea_code) 
	reghdfe treat2 $X if qx_type != 1, absorb(ea_code) cluster(ea_code) 
	reghdfe treat2 $X if qx_type != 0, absorb(ea_code) cluster(ea_code) 

	********
	balancetable (mean if qx_type == 0) (mean if qx_type == 1) 	(mean if qx_type == 2) (diff treat1 if qx_type != 2)  (diff treat2 if qx_type != 1) (diff treat2 if qx_type != 0) $X using "$tables\Table2.xlsx", cov(i.ea_code) vce(cluster ea_code) ctitles("Control" "LOA" "ESR" "LOA vs Control" "ESR vs Control"  "ESR vs LOA") wide(mean pval) pvalues modify varla sheet(PanelA)
	
	
	*sleep 60000
	putexcel set "$tables\Table1.xlsx", modify sheet(PanelA, replace) 
	
	putexcel B1="Mean" C1="SD"  D1="Min" E1="Max" F1="Observations"	

	local i = 2
	foreach x in hh_members dependency_ratio area_residence high_income food_insecure foreign_remittance nfe agriculture {
		local ytitle : var label `x'
		sum `x' if selected==1, d
		putexcel A`i'="`ytitle'" 
		putexcel B`i'= `r(mean)', nformat(number_d2)
		putexcel C`i'=`r(sd)', nformat(number_d2)
		putexcel D`i'=`r(min)'
		putexcel E`i'=`r(max)'
		putexcel F`i'=`r(N)'
		
		local i = `i' + 1	
		*sleep 10000
}

	restore
	
*-------------------------------------------------------------------------------
*                                     MODELS
*-------------------------------------------------------------------------------

use "$baseclean\master_data.dta", clear

**# Table 3: Survey Methods' Impacts on the Reporting of Labor Market Outcomes #

local lasso1 female age high_school read_write never_married access_cellphone access_internet 
local outcomes `" "employment" "work" "'
local CL hhid

local append = "replace"

foreach outcome of local outcomes {
			
//LASSO
		dsregress `outcome' qx_typed1 qx_typed2, controls((i.ea_code) `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"

// RI P-VALUES
		ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' i.qx_type  `LASSO1', absorb(ea_code) cluster(`CL') 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]

		ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' i.qx_type  `LASSO1', absorb(ea_code) cluster(`CL') 
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

//ESTIMATION
		reghdfe `outcome' qx_typed1 qx_typed2 `LASSO1', absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'
//OUTPUT
		outreg2 using "$tables\Table3.xls", `append' noomitted label excel dec(3) addtext(RI pval LOA, "[`ri_1']",RI pval ESR, "[`ri_2']",Outcome Control Mean, `meanY') ctitle ("`outcome'")  
			local append = "append"
}


**# Table 4: Survey Methods' Heterogeneous Effects by Respondent Sex or Age #

local outcomes `" "employment" "work" "'
local CL hhid
local lasso1 female age high_school read_write never_married access_cellphone access_internet
			
local append = "replace"
foreach het in female youth {
foreach outcome of local outcomes {

// LASSO			
			dsregress `outcome' qx_typed1 qx_typed2 treat1_`het' treat2_`het', controls((i.ea_code `het') `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"
			local models `" "`outcome' qx_typed1 qx_typed2 `het' treat1_`het' treat2_`het' `LASSO1'" "'
			
// RI P-VALUES
	ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' `LASSO1', absorb(ea_code) cluster(`CL')  // P-value para el coeff T1 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]
			
	ritest qx_type (_b[1.qx_type#1.`het']), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' `LASSO1', absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x D
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

	ritest qx_type (_b[1.qx_type] + _b[1.qx_type#1.`het']), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het'  `LASSO1' , absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x D + T1
			mat p = r(p)
			local ri_3 : display %4.3f p[1,1]

	ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' `LASSO1', absorb(ea_code) cluster(`CL')  // P-value para el coeff T2 
			mat p = r(p)
			local ri_4 : display %4.3f p[1,1]
			
	ritest qx_type (_b[2.qx_type#1.`het']), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' `LASSO1', absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x D
			mat p = r(p)
			local ri_5 : display %4.3f p[1,1]

	ritest qx_type (_b[2.qx_type] + _b[2.qx_type#1.`het']), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' `LASSO1' , absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x D + T2
			mat p = r(p)
			local ri_6 : display %4.3f p[1,1]

//ESTIMATION			
			foreach model of local models {
			reghdfe `model', absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

				lincom qx_typed1 + treat1_`het'
				local sumcoef1: display %4.3f `r(estimate)'
				local secoef1:  display %4.3f `r(se)'
				local pvalue1: display %4.3f `r(p)'
				if `pvalue1'<0.1{
				local sig1 "*"
				}
				if `pvalue1'<0.05{
				local sig1 "**"
				}

				if `pvalue1'<0.01{
				local sig1 "***"
				}
				
				lincom qx_typed2 + treat2_`het'
				local sumcoef2: display %4.3f `r(estimate)'
				local secoef2:  display %4.3f `r(se)'
				local pvalue2: display %4.3f `r(p)'
				if `pvalue2'<0.1{
				local sig2 "*"
				}
				if `pvalue2'<0.05{
				local sig2 "**"
				}

				if `pvalue2'<0.01{
				local sig2 "***"
				}
// OUTPUT
	outreg2 using "$tables\Table4.xls", `append' noomitted label excel dec(3) addtext(LOA + LOA x D,`sumcoef1'`sig1',se1,"(`secoef1')", ESR + ESR x D,`sumcoef2'`sig2', se2,"(`secoef2')",RI pval LOA, "[`ri_1']",RI pval LOA x D, "[`ri_2']",RI pval LOA + LOA x D , "[`ri_3']",RI pval ESR, "[`ri_4']",RI pval ESR x D, "[`ri_5']",RI pval ESR + ESR x D, "[`ri_6']", Outcome Control Mean, `meanY')  
			local append = "append"
			local sig1 ""
			local sig2 ""
	}
}
}


**# Table 5: Heterogeneity for Employment and Work by Age #
local outcomes `" "employment" "work" "'
local CL hhid
local lasso1 female age high_school read_write never_married access_cellphone access_internet 

local append = "replace"

foreach i in 1 0 {
foreach outcome of local outcomes {		
			
//LASSO
	dsregress `outcome' qx_typed1 qx_typed2 treat1_youth treat2_youth if female==`i', controls((i.ea_code youth) `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"
			local models `" "`outcome' qx_typed1 qx_typed2 youth treat1_youth treat2_youth `LASSO1'" "'
//RI P-VALUES
	ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth `LASSO1' if female==`i', absorb(ea_code) cluster(`CL')  // P-value para el coeff T1 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]
			
	ritest qx_type (_b[1.qx_type#1.youth]), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth `LASSO1' if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x Youth
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

	ritest qx_type (_b[1.qx_type] + _b[1.qx_type#1.youth]), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth  `LASSO1' if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x Youth + T1
			mat p = r(p)
			local ri_3 : display %4.3f p[1,1]

	ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth `LASSO1' if female==`i', absorb(ea_code) cluster(`CL')  // P-value para el coeff T2 
			mat p = r(p)
			local ri_4 : display %4.3f p[1,1]
			
	ritest qx_type (_b[2.qx_type#1.youth]), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth `LASSO1' if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x Youth
			mat p = r(p)
			local ri_5 : display %4.3f p[1,1]

	ritest qx_type (_b[2.qx_type] + _b[2.qx_type#1.youth]), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth `LASSO1' if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x Youth + T2
			mat p = r(p)
			local ri_6 : display %4.3f p[1,1]
//ESTIMATION		
		foreach model of local models {
			reghdfe `model' if female==`i', absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

				lincom qx_typed1 + treat1_youth
				local sumcoef1: display %4.3f `r(estimate)'
				local secoef1:  display %4.3f `r(se)'
				local pvalue1: display %4.3f `r(p)'
				if `pvalue1'<0.1{
				local sig1 "*"
				}
				if `pvalue1'<0.05{
				local sig1 "**"
				}

				if `pvalue1'<0.01{
				local sig1 "***"
				}

				lincom qx_typed2 + treat2_youth
				local sumcoef2: display %4.3f `r(estimate)'
				local secoef2:  display %4.3f `r(se)'
				local pvalue2: display %4.3f `r(p)'
				if `pvalue2'<0.1{
				local sig2 "*"
				}
				if `pvalue2'<0.05{
				local sig2 "**"
				}

				if `pvalue2'<0.01{
				local sig2 "***"
				}
			
//OUTPUT
			outreg2 using "$tables\Table5.xls", `append' noomitted label excel dec(3) addtext(LOA + LOA x Youth,`sumcoef1'`sig1',se1,"(`secoef1')",ESR + ESR x Youth,`sumcoef2'`sig2', se2,"(`secoef2')",RI pval LOA, "[`ri_1']",RI pval LOA x Youth, "[`ri_2']",RI pval LOA + LOA x Youth , "[`ri_3']",RI pval ESR, "[`ri_4']",RI pval ESR x Youth, "[`ri_5']",RI pval ESR + ESR x Youth, "[`ri_6']", Outcome Control Mean, `meanY') ctitle ("`outcome'")  
			local append = "append"
			local sig1 ""
			local sig2 ""

		}
}
}

**# Table 6.  Differential Effects on Employment and Work Status by Prevalence of Informal Employment 

local outcomes `" "employment" "work" "'
local CL hhid
local lasso1 female age high_school read_write never_married access_cellphone access_internet 

local append = "replace"
local samples `" "female==1" "youth==1 & female==0" "'

foreach i of local samples {
foreach outcome of local outcomes {		

			local x ""
			if "`i'"=="female==1" {
				local x "informal_female_std"
			}
			if "`i'"=="youth==1 & female==0" {
				local x "informal_male_std"
			}
			
//LASSO
	dsregress `outcome' qx_typed1 qx_typed2 treat1_`x' treat2_`x' if `i', controls((`x') `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"
			local models `" "`outcome' qx_typed1 qx_typed2 `x' treat1_`x' treat2_`x' `LASSO1'" "'
			
//RI P-VALUES
	ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if `i',  cluster(`CL')  // P-value para el coeff T1 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]
			
	ritest qx_type (_b[1.qx_type#c.`x']), fixlevels(2) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if `i',  cluster(`CL') // P-value para el coeff T1 x `x'
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

	ritest qx_type (_b[1.qx_type] + _b[1.qx_type#c.`x']), fixlevels(2) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x'  `LASSO1' if `i',  cluster(`CL') // P-value para el coeff T1 x `x' + T1
			mat p = r(p)
			local ri_3 : display %4.3f p[1,1]

	ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if `i',  cluster(`CL')  // P-value para el coeff T2 
			mat p = r(p)
			local ri_4 : display %4.3f p[1,1]
			
	ritest qx_type (_b[2.qx_type#c.`x']), fixlevels(1) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if `i',  cluster(`CL') // P-value para el coeff T2 x `x'
			mat p = r(p)
			local ri_5 : display %4.3f p[1,1]

	ritest qx_type (_b[2.qx_type] + _b[2.qx_type#c.`x']), fixlevels(1) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if `i',  cluster(`CL') // P-value para el coeff T2 x `x' + T2
			mat p = r(p)
			local ri_6 : display %4.3f p[1,1]

//ESTIMATION		
		foreach model of local models {
			reghdfe `model' if `i',  cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

				lincom qx_typed1 + treat1_`x'
				local sumcoef1: display %4.3f `r(estimate)'
				local secoef1:  display %4.3f `r(se)'
				local pvalue1: display %4.3f `r(p)'
				if `pvalue1'<0.1{
				local sig1 "*"
				}
				if `pvalue1'<0.05{
				local sig1 "**"
				}

				if `pvalue1'<0.01{
				local sig1 "***"
				}

				lincom qx_typed2 + treat2_`x'
				local sumcoef2: display %4.3f `r(estimate)'
				local secoef2:  display %4.3f `r(se)'
				local pvalue2: display %4.3f `r(p)'
				if `pvalue2'<0.1{
				local sig2 "*"
				}
				if `pvalue2'<0.05{
				local sig2 "**"
				}

				if `pvalue2'<0.01{
				local sig2 "***"
				}
			
//OUTPUT
			outreg2 using "$tables\Table6.xls", `append' noomitted label excel dec(3) addtext(LOA + LOA x Employment in the informal sector in the EA,`sumcoef1'`sig1',se1,"(`secoef1')",ESR + ESR x Employment in the informal sector in the EA,`sumcoef2'`sig2', se2,"(`secoef2')",RI pval LOA, "[`ri_1']",RI pval LOA x Employment in the informal sector in the EA, "[`ri_2']",RI pval LOA + LOA x Employment in the informal sector in the EA , "[`ri_3']",RI pval ESR, "[`ri_4']",RI pval ESR x Employment in the informal sector in the EA, "[`ri_5']",RI pval ESR + ESR x Employment in the informal sector in the EA, "[`ri_6']", Outcome Control Mean, `meanY') ctitle ("`outcome'")  
			local append = "append"
			local sig1 ""
			local sig2 ""

		}
}
}


**# Table 7.  Differential Effects on Employment and Work Status by Exposure to Social Norms Related to Housework
local outcomes `" "employment" "work" "'
local CL hhid
local lasso1 female age high_school read_write never_married access_cellphone access_internet 

local append = "replace"

foreach i in 1 0 {
foreach outcome of local outcomes {		

			local x "domestic_female"
			
//LASSO
	dsregress `outcome' qx_typed1 qx_typed2 treat1_`x' treat2_`x' if female==`i', controls((`x') `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"
			local models `" "`outcome' qx_typed1 qx_typed2 `x' treat1_`x' treat2_`x' `LASSO1'" "'
			
//RI P-VALUES
	ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if female==`i',  cluster(`CL')  // P-value para el coeff T1 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]
			
	ritest qx_type (_b[1.qx_type#c.`x']), fixlevels(2) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if female==`i',  cluster(`CL') // P-value para el coeff T1 x `x'
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

	ritest qx_type (_b[1.qx_type] + _b[1.qx_type#c.`x']), fixlevels(2) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x'  `LASSO1' if female==`i',  cluster(`CL') // P-value para el coeff T1 x `x' + T1
			mat p = r(p)
			local ri_3 : display %4.3f p[1,1]

	ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if female==`i',  cluster(`CL')  // P-value para el coeff T2 
			mat p = r(p)
			local ri_4 : display %4.3f p[1,1]
			
	ritest qx_type (_b[2.qx_type#c.`x']), fixlevels(1) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if female==`i',  cluster(`CL') // P-value para el coeff T2 x `x'
			mat p = r(p)
			local ri_5 : display %4.3f p[1,1]

	ritest qx_type (_b[2.qx_type] + _b[2.qx_type#c.`x']), fixlevels(1) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if female==`i',  cluster(`CL') // P-value para el coeff T2 x `x' + T2
			mat p = r(p)
			local ri_6 : display %4.3f p[1,1]

//ESTIMATION		
		foreach model of local models {
			reghdfe `model' if female==`i',  cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

				lincom qx_typed1 + treat1_`x'
				local sumcoef1: display %4.3f `r(estimate)'
				local secoef1:  display %4.3f `r(se)'
				local pvalue1: display %4.3f `r(p)'
				if `pvalue1'<0.1{
				local sig1 "*"
				}
				if `pvalue1'<0.05{
				local sig1 "**"
				}

				if `pvalue1'<0.01{
				local sig1 "***"
				}

				lincom qx_typed2 + treat2_`x'
				local sumcoef2: display %4.3f `r(estimate)'
				local secoef2:  display %4.3f `r(se)'
				local pvalue2: display %4.3f `r(p)'
				if `pvalue2'<0.1{
				local sig2 "*"
				}
				if `pvalue2'<0.05{
				local sig2 "**"
				}

				if `pvalue2'<0.01{
				local sig2 "***"
				}
			
//OUTPUT
			outreg2 using "$tables\Table7.xls", `append' noomitted label excel dec(3) addtext(LOA + LOA x Average time spent on housework ,`sumcoef1'`sig1',se1,"(`secoef1')",ESR + ESR x Average time spent on housework,`sumcoef2'`sig2', se2,"(`secoef2')",RI pval LOA, "[`ri_1']",RI pval LOA x Average time spent on housework , "[`ri_2']",RI pval LOA + LOA x Average time spent on housework , "[`ri_3']",RI pval ESR, "[`ri_4']",RI pval ESR x Average time spent on housework, "[`ri_5']",RI pval ESR + ESR x Average time spent on housework, "[`ri_6']", Outcome Control Mean, `meanY') ctitle ("`outcome'")  
			local append = "append"
			local sig1 ""
			local sig2 ""

		}
}
}

*********************************************************************
* 								FIGURES
*********************************************************************
**# Figure 2:  Effects on Employment and Work Status by Prevalence of Informal Employment and Sex
reghdfe employment female informal_sector_share_std qx_typed1 qx_typed2 treat1_female treat2_female informal_sex treat1_informal_sector_share treat2_informal_sector_share treat1_informal_sex treat2_informal_sex access_cellphone high_school never_married read_write, cluster(hhid) 
nlcom (lin_1: _b[qx_typed1]) ///
	  (lin_2: _b[qx_typed2]) ///
      (lin_3: _b[qx_typed1] + _b[treat1_informal_sector_share]) ///
      (lin_4: _b[qx_typed2] + _b[treat2_informal_sector_share]) ///
	  (lin_5: _b[qx_typed1] + _b[treat1_female]) ///
	  (lin_6: _b[qx_typed2] + _b[treat2_female]) ///
	  (lin_7: _b[qx_typed1] + _b[treat1_female] + _b[treat1_informal_sector_share] + _b[treat1_informal_sex]) ///
	  (lin_8: _b[qx_typed2] + _b[treat2_female] + _b[treat2_informal_sector_share] + _b[treat2_informal_sex]) , post
est sto nlcom4

reghdfe work female informal_sector_share_std qx_typed1 qx_typed2 treat1_female treat2_female informal_sex treat1_informal_sector_share treat2_informal_sector_share treat1_informal_sex treat2_informal_sex access_cellphone high_school never_married, cluster(hhid) 
nlcom (lin_1: _b[qx_typed1]) ///
	  (lin_2: _b[qx_typed2]) ///
      (lin_3: _b[qx_typed1] + _b[treat1_informal_sector_share]) ///
      (lin_4: _b[qx_typed2] + _b[treat2_informal_sector_share]) ///
	  (lin_5: _b[qx_typed1] + _b[treat1_female]) ///
	  (lin_6: _b[qx_typed2] + _b[treat2_female]) ///
	  (lin_7: _b[qx_typed1] + _b[treat1_female] + _b[treat1_informal_sector_share] + _b[treat1_informal_sex]) ///
	  (lin_8: _b[qx_typed2] + _b[treat2_female] + _b[treat2_informal_sector_share] + _b[treat2_informal_sex]) , post
est sto nlcom5


***AGREGADA

	coefplot nlcom4 || nlcom5 ,  graphregion(color(white)) ciopts(recast(rcap)) xline(0)coeflabels(lin_1 = "Effects of LOA on men in EAs with low informal employment"  lin_2= "Effects of ESR on men in EAs with low informal employment" lin_3="Effects of LOA on men in EAs with high informal employment" lin_4="Effects of ESR on men in EAs with high informal employment" lin_5="	Effects of LOA on women in EAs with low informal employment" lin_6="Effects of ESR on women in EAs with low informal employment" lin_7="Effects of LOA on women in EAs with high informal employment" lin_8="Effects of ESR on women in EAs with high informal employment")  bylabels( "Employed" "Working") byopts(row(1))  order(lin_7 lin_5 lin_8 lin_6) levels(90)  ylabel(,labsize(medsmall)) xlabel(,labsize(medlarge)) keep(lin_5 lin_6 lin_7 lin_8) name(panelA, replace) 

	gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy

reghdfe employment youth informal_male_std qx_typed1 qx_typed2 treat1_youth treat2_youth informal_youth treat1_informal_male_std treat2_informal_male_std treat1_informal_youth treat2_informal_youth access_cellphone  never_married read_write if female==0, cluster(hhid) 
nlcom (lin_12: _b[qx_typed1]) ///
	  (lin_22: _b[qx_typed2]) ///
      (lin_32: _b[qx_typed1] + _b[treat1_informal_male_std]) ///
      (lin_42: _b[qx_typed2] + _b[treat2_informal_male_std]) ///
	  (lin_52: _b[qx_typed1] + _b[treat1_youth]) ///
	  (lin_62: _b[qx_typed2] + _b[treat2_youth]) ///
	  (lin_72: _b[qx_typed1] + _b[treat1_youth] + _b[treat1_informal_male_std] + _b[treat1_informal_youth]) ///
	  (lin_82: _b[qx_typed2] + _b[treat2_youth] + _b[treat2_informal_male_std] + _b[treat2_informal_youth]) , post
est sto nlcom42

reghdfe work youth informal_male_std qx_typed1 qx_typed2 treat1_youth treat2_youth informal_youth treat1_informal_male_std treat2_informal_male_std treat1_informal_youth treat2_informal_youth access_cellphone never_married if female==0, cluster(hhid) 
nlcom (lin_12: _b[qx_typed1]) ///
	  (lin_22: _b[qx_typed2]) ///
      (lin_32: _b[qx_typed1] + _b[treat1_informal_male_std]) ///
      (lin_42: _b[qx_typed2] + _b[treat2_informal_male_std]) ///
	  (lin_52: _b[qx_typed1] + _b[treat1_youth]) ///
	  (lin_62: _b[qx_typed2] + _b[treat2_youth]) ///
	  (lin_72: _b[qx_typed1] + _b[treat1_youth] + _b[treat1_informal_male_std] + _b[treat1_informal_youth]) ///
	  (lin_82: _b[qx_typed2] + _b[treat2_youth] + _b[treat2_informal_male_std] + _b[treat2_informal_youth]) , post
est sto nlcom52


***AGREGADA

	coefplot nlcom42 || nlcom52 ,  graphregion(color(white)) ciopts(recast(rcap)) xline(0) coeflabels(lin_12 = "Effects of LOA on adult men in EAs with low informal employment"  lin_22= "Effects of ESR on adult men in EAs with low informal employment" lin_32="Effects of LOA on adult men in EAs with high informal employment" lin_42="Effects of ESR on adult men in EAs with high informal employment" lin_52="Effects of LOA on young men in EAs with low informal employment" lin_62="Effects of ESR on young men in EAs with low informal employment" lin_72="Effects of LOA on young men in EAs with high informal employment" lin_82="Effects of ESR on young men in EAs with high informal employment")  bylabels( "Employed" "Working") byopts(row(1)) order(lin_72  lin_52  lin_82 lin_62) levels(90)  ylabel(,labsize(medsmall)) xlabel(,labsize(medlarge)) keep(lin_52 lin_62 lin_72 lin_82) name(panelB, replace)

	gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
	*gr_edit .plotregion1.subtitle[1].style.editstyle size(small) editcopy
	
	graph combine panelA, title(Panel A. Prevalence of Informal Employment and Sex) name(grcol1,replace)
	graph combine panelB, title(Panel B. Prevalence of Informal Employment and Age) name(grcol2,replace)
	graph combine grcol1 grcol2, rows(2)
	
	gr_edit .plotregion1.graph1.plotregion1.graph1.plotregion1.subtitle[1].style.editstyle size(medlarge) editcopy
// subtitle[1] size
	gr_edit .plotregion1.graph2.plotregion1.graph1.plotregion1.subtitle[1].style.editstyle size(medlarge) editcopy
// subtitle[1] size
	gr_edit .plotregion1.graph1.plotregion1.graph1.plotregion1.xaxis1[1].reset_rule -0.2 0.4 0.2 , tickset(major) ruletype(range) 
	// xaxis1[1] edits
	gr_edit .plotregion1.graph1.plotregion1.graph1.plotregion1.xaxis1[2].reset_rule -0.2 0.4 0.2 , tickset(major) ruletype(range) 
// xaxis1[2] edits

	graph export "$figures\Figure2.png", replace
	
**# Figure 3: Effects on Employment and Work Status by Exposure to Social Norms Related to Housework

reghdfe employment female domestic_female qx_typed1 qx_typed2 treat1_female treat2_female domestic_female_sex treat1_domestic_female treat2_domestic_female treat1_domestic_female_sex treat2_domestic_female_sex access_cellphone high_school never_married read_write, cluster(hhid) 
nlcom (lin_1: _b[qx_typed1]) ///
	  (lin_2: _b[qx_typed2]) ///
      (lin_3: _b[qx_typed1] + _b[treat1_domestic_female]) ///
      (lin_4: _b[qx_typed2] + _b[treat2_domestic_female]) ///
	  (lin_5: _b[qx_typed1] + _b[treat1_female]) ///
	  (lin_6: _b[qx_typed2] + _b[treat2_female]) ///
	  (lin_7: _b[qx_typed1] + _b[treat1_female] + _b[treat1_domestic_female] + _b[treat1_domestic_female_sex]) ///
	  (lin_8: _b[qx_typed2] + _b[treat2_female] + _b[treat2_domestic_female] + _b[treat2_domestic_female_sex]) , post
est sto nlcom4

reghdfe work female domestic_female qx_typed1 qx_typed2 treat1_female treat2_female domestic_female_sex treat1_domestic_female treat2_domestic_female treat1_domestic_female_sex treat2_domestic_female_sex access_cellphone high_school never_married, cluster(hhid) 
nlcom (lin_1: _b[qx_typed1]) ///
	  (lin_2: _b[qx_typed2]) ///
      (lin_3: _b[qx_typed1] + _b[treat1_domestic_female]) ///
      (lin_4: _b[qx_typed2] + _b[treat2_domestic_female]) ///
	  (lin_5: _b[qx_typed1] + _b[treat1_female]) ///
	  (lin_6: _b[qx_typed2] + _b[treat2_female]) ///
	  (lin_7: _b[qx_typed1] + _b[treat1_female] + _b[treat1_domestic_female] + _b[treat1_domestic_female_sex]) ///
	  (lin_8: _b[qx_typed2] + _b[treat2_female] + _b[treat2_domestic_female] + _b[treat2_domestic_female_sex]) , post
est sto nlcom5


***AGREGADA

	coefplot nlcom4 || nlcom5 ,  graphregion(color(white)) ciopts(recast(rcap)) xline(0)coeflabels(lin_1 = "Effects of LOA on men exposed to less domestic obligations"  lin_2= "Effects of ESR on men exposed to less domestic obligations" lin_3="Effects of LOA on men exposed to more domestic obligations" lin_4="Effects of ESR on men exposed to more domestic obligations" lin_5="Effects of LOA on women exposed to less domestic obligations" lin_6="Effects of ESR on women exposed to less domestic obligations" lin_7="Effects of LOA on women exposed to more domestic obligations" lin_8="Effects of ESR on women exposed to more domestic obligations")  bylabels( "Employed" "Working") byopts(row(1))  order(lin_7 lin_3 lin_5 lin_1 lin_8 lin_4 lin_6 lin_2) levels(90)  ylabel(,labsize(vsmall)) xlabel(,labsize(small))

	
	gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
	gr_edit .plotregion1.subtitle[1].style.editstyle size(small) editcopy
	
	graph export "$figures\Figure3.png", replace
********************************************************************************

** Delete .txt files that have been created using `outreg2'
cd "$tables"
shell erase *.txt
	