******************************************************************
**  Measuring Women's and Youths' Informal Work in Non-Urban    **
**             Settings: Evidence from El Salvador              **
**                                                              **
**                                                              **
**  Country: El Salvador	  Date:  September 2022           	**
**                                                              **
**  Program Name:  03_main_tables_figures.do	                **
**                                                              **
**  Input Data Sets:                                            **
**		"$baseclean\master_data.dta"    	   	           	    **
**                                                              **
**  Description:                                                **
**      Create appendix tables 			 	    	            **
**                                                              **
**  Number of HHs:  1008                                        **
**                                                              **
**  Household:   hhid  	    			  						**
**                                                              **
**  Program first written: September, 2022 (Steffanny Romero)  	**
**  Program last revised:  April, 2024      		            **
**                                                              **
******************************************************************
clear all
set more off

set seed 487361

**# Table A3: Mean Characteristics of the Study Participants vs. Salvadorians
	use "$baseclean\master_data.dta", clear
	
	preserve
	collapse (sum) access_cellphone, by(hhid)
	gen access_cellphone_=access_cellphone>0
	drop access_cellphone
	ren access_cellphone_ access_cellphone
	tempfile access_cellphone
	save `access_cellphone'
	restore
	keep if selected==1
	drop access_cellphone
	merge m:1 hhid using `access_cellphone', nogen
	
	la var access_cellphone "Access to mobile phone"

	keep age female high_school read_write never_married access_cellphone access_internet hh_members main depid
	
	append using "$intermed\EHPM 2022_restringida.dta", gen(ehpm)

	global variables age female high_school read_write never_married access_cellphone access_internet
	
	replace fac00=1 if fac00 ==.
	
	balancetable ehpm $variables using "$tables\TableA3.xlsx" [aw=fac00], wide(mean pval) pvalues staraux replace ctitles("Study Sample" "EHPM Usulután and San Salvador" "P-val. Diff.") varla sheet(Columns 1 to 3)
	
	*sleep 10000
	
	preserve
	keep if r004==11 | depid==11
	balancetable ehpm $variables using "$tables\TableA3.xlsx" [aw=fac00], wide(mean pval) pvalues staraux modify ctitles("Study Sample Usulutan" "EHPM Usulutan" "P-val. Diff.") varla sheet(Columns 4 to 6)
	restore

	*sleep 10000
	
	preserve
	keep if r004==6 | depid==6
	balancetable ehpm $variables using "$tables\TableA3.xlsx" [aw=fac00], wide(mean pval) pvalues staraux modify ctitles("Study Sample San Salvador" "EHPM San Salvador" "P-val. Diff.") varla sheet(Columns 7 to 9)
	restore

**# Table A4: Original and Substitute Household Characteristic Means
	use "$baseclean\master_data.dta", clear
	
	gen replaced=type_hh==2

	global X female age high_school read_write never_married access_cellphone access_internet 

	balancetable replaced $X if selected==1 using "$tables\TableA4.xlsx", wide(mean pval)  pvalues nostars nopar replace ctitles("Original Household" "Substitute Household" "P-val. Difference") varla sheet(PANEL B)
	*sleep 10000	
	preserve
	keep if main==1 // una observación por hogar

	global X hh_members dependency_ratio area_residence high_income food_insecure foreign_remittance nfe agriculture

	balancetable replaced $X using "$tables\TableA4.xlsx", wide(mean pval)  pvalues nostars nopar modify ctitles("Original Household" "Substitute Household" "P-val. Difference") varla sheet(PANEL A)
	restore
	
**# Table A6. Summary Statistics for Variables Used for the Mechanisms Analysis
	use "$baseclean\master_data.dta", clear

	putexcel set "$tables\TableA6.xlsx", replace 
	
	putexcel B1="Mean" C1="SD" D1="Median" E1="Min" F1="Max" G1="N"	

	local i = 2
	foreach x in informal_sector_female informal_sector_male domestic_female informal_female_std informal_male_std  {
		local ytitle : var label `x'
		sum `x' if selected==1, d
		putexcel A`i'="`ytitle'" 
		putexcel B`i'= `r(mean)', nformat(number_d2)
		putexcel C`i'=`r(sd)', nformat(number_d2)
		putexcel D`i'=`r(p50)', nformat(number_d2)
		putexcel E`i'=`r(min)'
		putexcel F`i'=`r(max)'
		putexcel G`i'=`r(N)'
		
		local i = `i' + 1					
}

// Regressions 	

clear all
set more off
set seed 487361

use "$baseclean\master_data.dta", clear

**# Table A7.  Differential Effects on Employment and Work Status by Prevalence of Peers' Informal Employment

local outcomes `" "employment" "work" "'
local CL hhid
local lasso1 female age high_school read_write never_married access_cellphone access_internet 

local append = "replace"
local samples `" "female==0" "youth==0 & female==0" "'

foreach i of local samples {
foreach outcome of local outcomes {		

			local x "informal_male_std"
			
//LASSO
	dsregress `outcome' qx_typed1 qx_typed2 treat1_`x' treat2_`x' if `i', controls((`x') `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"
			local models `" "`outcome' qx_typed1 qx_typed2 `x' treat1_`x' treat2_`x' `LASSO1'" "'
			
//RI P-VALUES
	ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if `i',  cluster(`CL')  // P-value para el coeff T1 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]
			
	ritest qx_type (_b[1.qx_type#c.`x']), fixlevels(2) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if `i',  cluster(`CL') // P-value para el coeff T1 x `x'
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

	ritest qx_type (_b[1.qx_type] + _b[1.qx_type#c.`x']), fixlevels(2) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x'  `LASSO1' if `i',  cluster(`CL') // P-value para el coeff T1 x `x' + T1
			mat p = r(p)
			local ri_3 : display %4.3f p[1,1]

	ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if `i',  cluster(`CL')  // P-value para el coeff T2 
			mat p = r(p)
			local ri_4 : display %4.3f p[1,1]
			
	ritest qx_type (_b[2.qx_type#c.`x']), fixlevels(1) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if `i',  cluster(`CL') // P-value para el coeff T2 x `x'
			mat p = r(p)
			local ri_5 : display %4.3f p[1,1]

	ritest qx_type (_b[2.qx_type] + _b[2.qx_type#c.`x']), fixlevels(1) reps(1000) seed(487361) : reghdfe `outcome' qx_type##c.`x' `LASSO1' if `i',  cluster(`CL') // P-value para el coeff T2 x `x' + T2
			mat p = r(p)
			local ri_6 : display %4.3f p[1,1]

//ESTIMATION		
		foreach model of local models {
			reghdfe `model' if `i',  cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

				lincom qx_typed1 + treat1_`x'
				local sumcoef1: display %4.3f `r(estimate)'
				local secoef1:  display %4.3f `r(se)'
				local pvalue1: display %4.3f `r(p)'
				if `pvalue1'<0.1{
				local sig1 "*"
				}
				if `pvalue1'<0.05{
				local sig1 "**"
				}

				if `pvalue1'<0.01{
				local sig1 "***"
				}

				lincom qx_typed2 + treat2_`x'
				local sumcoef2: display %4.3f `r(estimate)'
				local secoef2:  display %4.3f `r(se)'
				local pvalue2: display %4.3f `r(p)'
				if `pvalue2'<0.1{
				local sig2 "*"
				}
				if `pvalue2'<0.05{
				local sig2 "**"
				}

				if `pvalue2'<0.01{
				local sig2 "***"
				}
			
//OUTPUT
			outreg2 using "$tables\TableA7.xls", `append' noomitted label excel dec(3) addtext(LOA + LOA x Informal employment in the EA,`sumcoef1'`sig1',se1,"(`secoef1')",ESR + ESR x Informal employment in the EA,`sumcoef2'`sig2', se2,"(`secoef2')",RI pval LOA, "[`ri_1']",RI pval LOA x Informal employment in the EA, "[`ri_2']",RI pval LOA + LOA x Informal employment in the EA , "[`ri_3']",RI pval ESR, "[`ri_4']",RI pval ESR x Informal employment in the EA, "[`ri_5']",RI pval ESR + ESR x Informal employment in the EA, "[`ri_6']", Outcome Control Mean, `meanY') ctitle ("`outcome'")  
			local append = "append"
			local sig1 ""
			local sig2 ""

		}
}
}
	
**# Table A8. Differential Effects on Employment and Work Status by Prevalence of Informal Employment

local outcomes `" "employment" "work" "'
local CL hhid
local lasso1 female age high_school read_write never_married access_cellphone access_internet 

local append = "replace"

foreach outcome of local outcomes {		
			
//LASSO
	dsregress `outcome' qx_typed1 qx_typed2 treat1_female treat2_female treat1_informal_sector_share treat2_informal_sector_share treat1_informal_sex treat2_informal_sex, controls((female informal_sector_share_std informal_sex) `lasso1' ) rseed(487361) vce(cluster hhid)
			local LASSO1 "`e(controls_sel)'"
			local models `" "`outcome' female informal_sector_share_std qx_typed1 qx_typed2 treat1_female treat2_female informal_sex treat1_informal_sector_share treat2_informal_sector_share treat1_informal_sex treat2_informal_sex `LASSO1'" "'
			

//ESTIMATION		
		foreach model of local models {
			reghdfe `model' ,  cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

lincom qx_typed1 
local coef5: display %4.3f `r(estimate)'
local pvalue5: display %4.3f `r(p)'

if `pvalue5'<0.1{
local sig5 "*"
}
if `pvalue5'<0.05{
local sig5 "**"
}

if `pvalue5'<0.01{
local sig5 "***"
}


lincom qx_typed1 + treat1_informal_sector_share
local coef6: display %4.3f `r(estimate)'
local pvalue6: display %4.3f `r(p)'
if `pvalue6'<0.1{
local sig6 "*"
}
if `pvalue6'<0.05{
local sig6 "**"
}
if `pvalue6'<0.01{
local sig6 "***"
}

lincom qx_typed1 + treat1_female
local coef7: display %4.3f `r(estimate)'
local pvalue7: display %4.3f `r(p)'

if `pvalue7'<0.1{
local sig7 "*"
}
if `pvalue7'<0.05{
local sig7 "**"
}
if `pvalue7'<0.01{
local sig7 "***"
}

lincom qx_typed1 + treat1_female + treat1_informal_sector_share + treat1_informal_sex
local coef8: display %4.3f `r(estimate)'
local pvalue8: display %4.3f `r(p)'
if `pvalue8'<0.05{
local sig8 "**"
}

if `pvalue8'<0.01{
local sig8 "***"
}

if `pvalue8'<0.1{
local sig8 "*"
}


lincom qx_typed2 
local coef13: display %4.3f `r(estimate)'
local pvalue13: display %4.3f `r(p)'

if `pvalue13'<0.1{
local sig13 "*"
}
if `pvalue13'<0.05{
local sig13 "**"
}

if `pvalue13'<0.01{
local sig13 "***"
}


lincom qx_typed2 + treat2_informal_sector_share
local coef14: display %4.3f `r(estimate)'
local pvalue14: display %4.3f `r(p)'
if `pvalue14'<0.1{
local sig14 "*"
}
if `pvalue14'<0.05{
local sig14 "**"
}
if `pvalue14'<0.01{
local sig14 "***"
}

lincom qx_typed2 + treat2_female
local coef15: display %4.3f `r(estimate)'
local pvalue15: display %4.3f `r(p)'

if `pvalue15'<0.1{
local sig15 "*"
}
if `pvalue15'<0.05{
local sig15 "**"
}
if `pvalue15'<0.01{
local sig15 "***"
}

lincom qx_typed2 + treat2_female + treat2_informal_sector_share + treat2_informal_sex
local coef16: display %4.3f `r(estimate)'
local pvalue16: display %4.3f `r(p)'
if `pvalue16'<0.05{
local sig16 "**"
}

if `pvalue16'<0.01{
local sig16 "***"
}

if `pvalue16'<0.1{
local sig16 "*"
}	

//OUTPUT
			outreg2 using "$tables\TableA8.xls", `append' noomitted label excel dec(3) addtext(Outcome Control Mean, `meanY', Effects of LOA on men in EAs with low informal employment, `coef5'`sig5', Effects of LOA on men in EAs with high informal employment, `coef6'`sig6', Effects of LOA on women in EAs with low informal employment, `coef7'`sig7', Effects of LOA on women in EAs with high informal employment, `coef8'`sig8', Effects of ESR on men in EAs with low informal employment, `coef13'`sig13', Effects of ESR on men in EAs with high informal employment, `coef14'`sig14', Effects of ESR on women in EAs with low informal employment, `coef15'`sig15', Effects of ESR on women in EAs with high informal employment, `coef16'`sig16')
			local append = "append"
local sig5 ""
local sig6 ""
local sig7 ""
local sig8 ""
local sig13 ""
local sig14 ""
local sig15 ""
local sig16 ""

		}
}

**# Table A9. Differential Effects on Employment and Work Status by Prevalence of Informal Employment
local outcomes `" "employment" "work" "'
local CL hhid
local lasso1 female age high_school read_write never_married access_cellphone access_internet 

local append = "replace"

foreach outcome of local outcomes {		
			
//LASSO
	dsregress `outcome' qx_typed1 qx_typed2 treat1_youth treat2_youth treat1_informal_male_std treat2_informal_male_std treat1_informal_youth treat2_informal_youth if female==0, controls((youth informal_male_std informal_youth) `lasso1' ) rseed(487361) vce(cluster hhid)
			local LASSO1 "`e(controls_sel)'"
			local models `" "`outcome' youth informal_male_std qx_typed1 qx_typed2 treat1_youth treat2_youth informal_youth treat1_informal_male_std treat2_informal_male_std treat1_informal_youth treat2_informal_youth `LASSO1'" "'
			

//ESTIMATION		
		foreach model of local models {
			reghdfe `model' if female==0,  cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'



lincom qx_typed1 
local coef5: display %4.3f `r(estimate)'
local pvalue5: display %4.3f `r(p)'

if `pvalue5'<0.1{
local sig5 "*"
}
if `pvalue5'<0.05{
local sig5 "**"
}

if `pvalue5'<0.01{
local sig5 "***"
}


lincom qx_typed1 + treat1_informal_male_std
local coef6: display %4.3f `r(estimate)'
local pvalue6: display %4.3f `r(p)'
if `pvalue6'<0.1{
local sig6 "*"
}
if `pvalue6'<0.05{
local sig6 "**"
}
if `pvalue6'<0.01{
local sig6 "***"
}

lincom qx_typed1 + treat1_youth
local coef7: display %4.3f `r(estimate)'
local pvalue7: display %4.3f `r(p)'

if `pvalue7'<0.1{
local sig7 "*"
}
if `pvalue7'<0.05{
local sig7 "**"
}
if `pvalue7'<0.01{
local sig7 "***"
}

lincom qx_typed1 + treat1_youth + treat1_informal_male_std + treat1_informal_youth
local coef8: display %4.3f `r(estimate)'
local pvalue8: display %4.3f `r(p)'
if `pvalue8'<0.05{
local sig8 "**"
}

if `pvalue8'<0.01{
local sig8 "***"
}

if `pvalue8'<0.1{
local sig8 "*"
}

lincom qx_typed2 
local coef13: display %4.3f `r(estimate)'
local pvalue13: display %4.3f `r(p)'

if `pvalue13'<0.1{
local sig13 "*"
}
if `pvalue13'<0.05{
local sig13 "**"
}

if `pvalue13'<0.01{
local sig13 "***"
}


lincom qx_typed2 + treat2_informal_male_std
local coef14: display %4.3f `r(estimate)'
local pvalue14: display %4.3f `r(p)'
if `pvalue14'<0.1{
local sig14 "*"
}
if `pvalue14'<0.05{
local sig14 "**"
}
if `pvalue14'<0.01{
local sig14 "***"
}

lincom qx_typed2 + treat2_youth
local coef15: display %4.3f `r(estimate)'
local pvalue15: display %4.3f `r(p)'

if `pvalue15'<0.1{
local sig15 "*"
}
if `pvalue15'<0.05{
local sig15 "**"
}
if `pvalue15'<0.01{
local sig15 "***"
}

lincom qx_typed2 + treat2_youth + treat2_informal_male_std + treat2_informal_youth
local coef16: display %4.3f `r(estimate)'
local pvalue16: display %4.3f `r(p)'
if `pvalue16'<0.05{
local sig16 "**"
}

if `pvalue16'<0.01{
local sig16 "***"
}

if `pvalue16'<0.1{
local sig16 "*"
}	

//OUTPUT
			outreg2 using "$tables\TableA9.xls", `append' noomitted label excel dec(3) addtext(Outcome Control Mean, `meanY', Effects of LOA on adult men in EAs with low informal employment, `coef5'`sig5', Effects of LOA on adult men in EAs with high informal employment, `coef6'`sig6', Effects of LOA on young men in EAs with low informal employment, `coef7'`sig7', Effects of LOA on young men in EAs with high informal employment, `coef8'`sig8', Effects of ESR on adult men in EAs with low informal employment, `coef13'`sig13', Effects of ESR on adult men in EAs with high informal employment, `coef14'`sig14', Effects of ESR on young men in EAs with low informal employment, `coef15'`sig15', Effects of ESR on young men in EAs with high informal employment, `coef16'`sig16')
			local append = "append"
local sig5 ""
local sig6 ""
local sig7 ""
local sig8 ""
local sig13 ""
local sig14 ""
local sig15 ""
local sig16 ""

}
}


**# Table A10. Differential Effects on Employment and Work Status by Exposure to Social Norms Related to Housework
local outcomes `" "employment" "work" "'
local CL hhid
local lasso1 female age high_school read_write never_married access_cellphone access_internet 

local append = "replace"

foreach outcome of local outcomes {		

			local x "domestic_female"
			
//LASSO
	dsregress `outcome' qx_typed1 qx_typed2 treat1_female treat2_female treat1_domestic_female treat2_domestic_female treat1_domestic_female_sex treat2_domestic_female_sex, controls((female domestic_female domestic_female_sex) `lasso1' ) rseed(487361) vce(cluster hhid)
			local LASSO1 "`e(controls_sel)'"
			local models `" "`outcome' female domestic_female qx_typed1 qx_typed2 treat1_female treat2_female domestic_female_sex treat1_domestic_female treat2_domestic_female treat1_domestic_female_sex treat2_domestic_female_sex `LASSO1'" "'
			

//ESTIMATION		
		foreach model of local models {
			reghdfe `model' ,  cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

lincom qx_typed1 
local coef5: display %4.3f `r(estimate)'
local pvalue5: display %4.3f `r(p)'

if `pvalue5'<0.1{
local sig5 "*"
}
if `pvalue5'<0.05{
local sig5 "**"
}

if `pvalue5'<0.01{
local sig5 "***"
}


lincom qx_typed1 + treat1_domestic_female
local coef6: display %4.3f `r(estimate)'
local pvalue6: display %4.3f `r(p)'
if `pvalue6'<0.1{
local sig6 "*"
}
if `pvalue6'<0.05{
local sig6 "**"
}
if `pvalue6'<0.01{
local sig6 "***"
}

lincom qx_typed1 + treat1_female
local coef7: display %4.3f `r(estimate)'
local pvalue7: display %4.3f `r(p)'

if `pvalue7'<0.1{
local sig7 "*"
}
if `pvalue7'<0.05{
local sig7 "**"
}
if `pvalue7'<0.01{
local sig7 "***"
}

lincom qx_typed1 + treat1_female + treat1_domestic_female + treat1_domestic_female_sex
local coef8: display %4.3f `r(estimate)'
local pvalue8: display %4.3f `r(p)'
if `pvalue8'<0.05{
local sig8 "**"
}

if `pvalue8'<0.01{
local sig8 "***"
}

if `pvalue8'<0.1{
local sig8 "*"
}

lincom qx_typed2 
local coef13: display %4.3f `r(estimate)'
local pvalue13: display %4.3f `r(p)'

if `pvalue13'<0.1{
local sig13 "*"
}
if `pvalue13'<0.05{
local sig13 "**"
}

if `pvalue13'<0.01{
local sig13 "***"
}


lincom qx_typed2 + treat2_domestic_female
local coef14: display %4.3f `r(estimate)'
local pvalue14: display %4.3f `r(p)'
if `pvalue14'<0.1{
local sig14 "*"
}
if `pvalue14'<0.05{
local sig14 "**"
}
if `pvalue14'<0.01{
local sig14 "***"
}

lincom qx_typed2 + treat2_female
local coef15: display %4.3f `r(estimate)'
local pvalue15: display %4.3f `r(p)'

if `pvalue15'<0.1{
local sig15 "*"
}
if `pvalue15'<0.05{
local sig15 "**"
}
if `pvalue15'<0.01{
local sig15 "***"
}

lincom qx_typed2 + treat2_female + treat2_domestic_female + treat2_domestic_female_sex
local coef16: display %4.3f `r(estimate)'
local pvalue16: display %4.3f `r(p)'
if `pvalue16'<0.05{
local sig16 "**"
}

if `pvalue16'<0.01{
local sig16 "***"
}

if `pvalue16'<0.1{
local sig16 "*"
}	

//OUTPUT
			outreg2 using "$tables\TableA10.xls", `append' noomitted label excel dec(3) addtext(Outcome Control Mean, `meanY', Effects of LOA on men exposed to less housework, `coef5'`sig5', Effects of LOA on men exposed to more housework, `coef6'`sig6', Effects of LOA on women exposed to less housework, `coef7'`sig7', Effects of LOA on women exposed to more housework, `coef8'`sig8', Effects of ESR on men exposed to less housework, `coef13'`sig13', Effects of ESR on men exposed to more housework, `coef14'`sig14', Effects of ESR on women exposed to less housework, `coef15'`sig15', Effects of ESR on women exposed to more housework, `coef16'`sig16')
			local append = "append"
local sig5 ""
local sig6 ""
local sig7 ""
local sig8 ""
local sig13 ""
local sig14 ""
local sig15 ""
local sig16 ""

*sleep 10000
}
}	

**# Table A11. The Survey Methods' Impacts on the Measurement of Labor Market Outcomes, Excluding Controls

local outcomes `" "employment" "work" "'
local CL hhid

local append = "replace"

foreach outcome of local outcomes {
			
// RI P-VALUES
		ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' i.qx_type  , absorb(ea_code) cluster(`CL') 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]

		ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' i.qx_type  , absorb(ea_code) cluster(`CL') 
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

//ESTIMATION
		reghdfe `outcome' qx_typed1 qx_typed2 , absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'
//OUTPUT
		outreg2 using "$tables\TableA11.xls", `append' noomitted label excel dec(3) addtext(RI pval LOA, "[`ri_1']",RI pval ESR, "[`ri_2']",Outcome Control Mean, `meanY') ctitle ("`outcome'")  
			local append = "append"
}


**# Table A12: The Survey Methods' Heterogeneous Effects by Respondent Sex and Age, Excluding Controls

local outcomes `" "employment" "work" "'
local CL hhid
			
local append = "replace"
foreach het in female youth {
foreach outcome of local outcomes {

	local models `" "`outcome' qx_typed1 qx_typed2 `het' treat1_`het' treat2_`het' " "'
			
// RI P-VALUES
	ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' , absorb(ea_code) cluster(`CL')  // P-value para el coeff T1 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]
			
	ritest qx_type (_b[1.qx_type#1.`het']), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' , absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x D
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

	ritest qx_type (_b[1.qx_type] + _b[1.qx_type#1.`het']), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het'   , absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x D + T1
			mat p = r(p)
			local ri_3 : display %4.3f p[1,1]

	ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' , absorb(ea_code) cluster(`CL')  // P-value para el coeff T2 
			mat p = r(p)
			local ri_4 : display %4.3f p[1,1]
			
	ritest qx_type (_b[2.qx_type#1.`het']), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' , absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x D
			mat p = r(p)
			local ri_5 : display %4.3f p[1,1]

	ritest qx_type (_b[2.qx_type] + _b[2.qx_type#1.`het']), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het'  , absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x D + T2
			mat p = r(p)
			local ri_6 : display %4.3f p[1,1]

//ESTIMATION			
			foreach model of local models {
			reghdfe `model', absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

				lincom qx_typed1 + treat1_`het'
				local sumcoef1: display %4.3f `r(estimate)'
				local secoef1:  display %4.3f `r(se)'
				local pvalue1: display %4.3f `r(p)'
				if `pvalue1'<0.1{
				local sig1 "*"
				}
				if `pvalue1'<0.05{
				local sig1 "**"
				}

				if `pvalue1'<0.01{
				local sig1 "***"
				}
				
				lincom qx_typed2 + treat2_`het'
				local sumcoef2: display %4.3f `r(estimate)'
				local secoef2:  display %4.3f `r(se)'
				local pvalue2: display %4.3f `r(p)'
				if `pvalue2'<0.1{
				local sig2 "*"
				}
				if `pvalue2'<0.05{
				local sig2 "**"
				}

				if `pvalue2'<0.01{
				local sig2 "***"
				}
// OUTPUT
	outreg2 using "$tables\TableA12.xls", `append' noomitted label excel dec(3) addtext(LOA + LOA x D,`sumcoef1'`sig1',se1,"(`secoef1')", ESR + ESR x D,`sumcoef2'`sig2', se2,"(`secoef2')",RI pval LOA, "[`ri_1']",RI pval LOA x D, "[`ri_2']",RI pval LOA + LOA x D , "[`ri_3']",RI pval ESR, "[`ri_4']",RI pval ESR x D, "[`ri_5']",RI pval ESR + ESR x D, "[`ri_6']", Outcome Control Mean, `meanY')  
			local append = "append"
			local sig1 ""
			local sig2 ""
	}
}
}


**# Table A13: Heterogeneity for Employment and Work by Age, Excluding Controls
local outcomes `" "employment" "work" "'
local CL hhid


local append = "replace"

foreach i in 1 0 {
foreach outcome of local outcomes {		
			
			local models `" "`outcome' qx_typed1 qx_typed2 youth treat1_youth treat2_youth " "'
//RI P-VALUES
	ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth  if female==`i', absorb(ea_code) cluster(`CL')  // P-value para el coeff T1 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]
			
	ritest qx_type (_b[1.qx_type#1.youth]), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth  if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x Youth
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

	ritest qx_type (_b[1.qx_type] + _b[1.qx_type#1.youth]), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth   if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x Youth + T1
			mat p = r(p)
			local ri_3 : display %4.3f p[1,1]

	ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth  if female==`i', absorb(ea_code) cluster(`CL')  // P-value para el coeff T2 
			mat p = r(p)
			local ri_4 : display %4.3f p[1,1]
			
	ritest qx_type (_b[2.qx_type#1.youth]), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth  if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x Youth
			mat p = r(p)
			local ri_5 : display %4.3f p[1,1]

	ritest qx_type (_b[2.qx_type] + _b[2.qx_type#1.youth]), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth  if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x Youth + T2
			mat p = r(p)
			local ri_6 : display %4.3f p[1,1]
//ESTIMATION		
		foreach model of local models {
			reghdfe `model' if female==`i', absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

				lincom qx_typed1 + treat1_youth
				local sumcoef1: display %4.3f `r(estimate)'
				local secoef1:  display %4.3f `r(se)'
				local pvalue1: display %4.3f `r(p)'
				if `pvalue1'<0.1{
				local sig1 "*"
				}
				if `pvalue1'<0.05{
				local sig1 "**"
				}

				if `pvalue1'<0.01{
				local sig1 "***"
				}

				lincom qx_typed2 + treat2_youth
				local sumcoef2: display %4.3f `r(estimate)'
				local secoef2:  display %4.3f `r(se)'
				local pvalue2: display %4.3f `r(p)'
				if `pvalue2'<0.1{
				local sig2 "*"
				}
				if `pvalue2'<0.05{
				local sig2 "**"
				}

				if `pvalue2'<0.01{
				local sig2 "***"
				}
			
//OUTPUT
			outreg2 using "$tables\TableA13.xls", `append' noomitted label excel dec(3) addtext(LOA + LOA x Youth,`sumcoef1'`sig1',se1,"(`secoef1')",ESR + ESR x Youth,`sumcoef2'`sig2', se2,"(`secoef2')",RI pval LOA, "[`ri_1']",RI pval LOA x Youth, "[`ri_2']",RI pval LOA + LOA x Youth , "[`ri_3']",RI pval ESR, "[`ri_4']",RI pval ESR x Youth, "[`ri_5']",RI pval ESR + ESR x Youth, "[`ri_6']", Outcome Control Mean, `meanY') ctitle ("`outcome'")  
			local append = "append"
			local sig1 ""
			local sig2 ""

		}
}
}

**# Table A14: The Survey Methods' Impacts on the Measurement of Labor Market Outcomes, Addressing the Substitution Protocol's Effects 
local lasso1 female age high_school read_write never_married access_cellphone access_internet 
local outcomes `" "employment" "work" "'
local CL hhid

local append = "replace"

foreach outcome of local outcomes {
			
//LASSO
		dsregress `outcome' qx_typed1 qx_typed2, controls((i.ea_code) `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"

// RI P-VALUES
		ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' i.qx_type  `LASSO1' access_cellphone access_internet, absorb(ea_code) cluster(`CL') 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]

		ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' i.qx_type  `LASSO1' access_cellphone access_internet, absorb(ea_code) cluster(`CL') 
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

//ESTIMATION
		reghdfe `outcome' qx_typed1 qx_typed2 `LASSO1' access_cellphone access_internet, absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'
//OUTPUT
		outreg2 using "$tables\TableA14.xls", `append' noomitted label excel dec(3) addtext(RI pval LOA, "[`ri_1']",RI pval ESR, "[`ri_2']",Outcome Control Mean, `meanY') ctitle ("`outcome'")  
			local append = "append"
}


**# Table A15:The Survey Methods' Heterogeneous Effects by Respondent Sex and Age, Addressing the Substitution Protocol's Effects

local outcomes `" "employment" "work" "'
local CL hhid
local lasso1 female age high_school read_write never_married access_cellphone access_internet
			
local append = "replace"
foreach het in female youth {
foreach outcome of local outcomes {

// LASSO			
			dsregress `outcome' qx_typed1 qx_typed2 treat1_`het' treat2_`het', controls((i.ea_code `het') `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"
			local models `" "`outcome' qx_typed1 qx_typed2 `het' treat1_`het' treat2_`het' `LASSO1' access_cellphone access_internet " "'
			
// RI P-VALUES
	ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' `LASSO1' access_cellphone access_internet, absorb(ea_code) cluster(`CL')  // P-value para el coeff T1 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]
			
	ritest qx_type (_b[1.qx_type#1.`het']), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' `LASSO1' access_cellphone access_internet, absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x D
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

	ritest qx_type (_b[1.qx_type] + _b[1.qx_type#1.`het']), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het'  `LASSO1' access_cellphone access_internet , absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x D + T1
			mat p = r(p)
			local ri_3 : display %4.3f p[1,1]

	ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' `LASSO1' access_cellphone access_internet, absorb(ea_code) cluster(`CL')  // P-value para el coeff T2 
			mat p = r(p)
			local ri_4 : display %4.3f p[1,1]
			
	ritest qx_type (_b[2.qx_type#1.`het']), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' `LASSO1' access_cellphone access_internet, absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x D
			mat p = r(p)
			local ri_5 : display %4.3f p[1,1]

	ritest qx_type (_b[2.qx_type] + _b[2.qx_type#1.`het']), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##`het' `LASSO1' access_cellphone access_internet , absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x D + T2
			mat p = r(p)
			local ri_6 : display %4.3f p[1,1]

//ESTIMATION			
			foreach model of local models {
			reghdfe `model', absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

				lincom qx_typed1 + treat1_`het'
				local sumcoef1: display %4.3f `r(estimate)'
				local secoef1:  display %4.3f `r(se)'
				local pvalue1: display %4.3f `r(p)'
				if `pvalue1'<0.1{
				local sig1 "*"
				}
				if `pvalue1'<0.05{
				local sig1 "**"
				}

				if `pvalue1'<0.01{
				local sig1 "***"
				}
				
				lincom qx_typed2 + treat2_`het'
				local sumcoef2: display %4.3f `r(estimate)'
				local secoef2:  display %4.3f `r(se)'
				local pvalue2: display %4.3f `r(p)'
				if `pvalue2'<0.1{
				local sig2 "*"
				}
				if `pvalue2'<0.05{
				local sig2 "**"
				}

				if `pvalue2'<0.01{
				local sig2 "***"
				}
// OUTPUT
	outreg2 using "$tables\TableA15.xls", `append' noomitted label excel dec(3) addtext(LOA + LOA x D,`sumcoef1'`sig1',se1,"(`secoef1')", ESR + ESR x D,`sumcoef2'`sig2', se2,"(`secoef2')",RI pval LOA, "[`ri_1']",RI pval LOA x D, "[`ri_2']",RI pval LOA + LOA x D , "[`ri_3']",RI pval ESR, "[`ri_4']",RI pval ESR x D, "[`ri_5']",RI pval ESR + ESR x D, "[`ri_6']", Outcome Control Mean, `meanY')  
			local append = "append"
			local sig1 ""
			local sig2 ""
	}
}
}


**# Table A16: Heterogeneity for Employment and Work by Age, Addressing the Substitution Protocol's Effects
local outcomes `" "employment" "work" "'
local CL hhid
local lasso1 female age high_school read_write never_married access_cellphone access_internet 

local append = "replace"

foreach i in 1 0 {
foreach outcome of local outcomes {		
			
//LASSO
	dsregress `outcome' qx_typed1 qx_typed2 treat1_youth treat2_youth if female==`i', controls((i.ea_code youth) `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"
			local models `" "`outcome' qx_typed1 qx_typed2 youth treat1_youth treat2_youth `LASSO1' access_cellphone access_internet" "'
//RI P-VALUES
	ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth `LASSO1' access_cellphone access_internet if female==`i', absorb(ea_code) cluster(`CL')  // P-value para el coeff T1 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]
			
	ritest qx_type (_b[1.qx_type#1.youth]), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth `LASSO1' access_cellphone access_internet if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x Youth
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

	ritest qx_type (_b[1.qx_type] + _b[1.qx_type#1.youth]), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth  `LASSO1' access_cellphone access_internet if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x Youth + T1
			mat p = r(p)
			local ri_3 : display %4.3f p[1,1]

	ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth `LASSO1' access_cellphone access_internet if female==`i', absorb(ea_code) cluster(`CL')  // P-value para el coeff T2 
			mat p = r(p)
			local ri_4 : display %4.3f p[1,1]
			
	ritest qx_type (_b[2.qx_type#1.youth]), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth `LASSO1' access_cellphone access_internet if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x Youth
			mat p = r(p)
			local ri_5 : display %4.3f p[1,1]

	ritest qx_type (_b[2.qx_type] + _b[2.qx_type#1.youth]), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##youth `LASSO1' access_cellphone access_internet if female==`i', absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x Youth + T2
			mat p = r(p)
			local ri_6 : display %4.3f p[1,1]
//ESTIMATION		
		foreach model of local models {
			reghdfe `model' if female==`i', absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

				lincom qx_typed1 + treat1_youth
				local sumcoef1: display %4.3f `r(estimate)'
				local secoef1:  display %4.3f `r(se)'
				local pvalue1: display %4.3f `r(p)'
				if `pvalue1'<0.1{
				local sig1 "*"
				}
				if `pvalue1'<0.05{
				local sig1 "**"
				}

				if `pvalue1'<0.01{
				local sig1 "***"
				}

				lincom qx_typed2 + treat2_youth
				local sumcoef2: display %4.3f `r(estimate)'
				local secoef2:  display %4.3f `r(se)'
				local pvalue2: display %4.3f `r(p)'
				if `pvalue2'<0.1{
				local sig2 "*"
				}
				if `pvalue2'<0.05{
				local sig2 "**"
				}

				if `pvalue2'<0.01{
				local sig2 "***"
				}
			
//OUTPUT
			outreg2 using "$tables\TableA16.xls", `append' noomitted label excel dec(3) addtext(LOA + LOA x Youth,`sumcoef1'`sig1',se1,"(`secoef1')",ESR + ESR x Youth,`sumcoef2'`sig2', se2,"(`secoef2')",RI pval LOA, "[`ri_1']",RI pval LOA x Youth, "[`ri_2']",RI pval LOA + LOA x Youth , "[`ri_3']",RI pval ESR, "[`ri_4']",RI pval ESR x Youth, "[`ri_5']",RI pval ESR + ESR x Youth, "[`ri_6']", Outcome Control Mean, `meanY') ctitle ("`outcome'")  
			local append = "append"
			local sig1 ""
			local sig2 ""

		}
}
}



**# Table A17: Participation in Employment and Work by Proxy Characteristics
local outcomes `" "employment" "work" "'
local CL hhid
local lasso1 female age high_school read_write never_married access_cellphone access_internet 

local append = "replace"

foreach outcome of local outcomes {		
foreach het in proxyfemale proxyhigh_school proxyspouse {
foreach i in 1 0 {
			
//LASSO
	dsregress `outcome' qx_typed1 if female==`i', controls((i.ea_code) `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"
			local models `" "`outcome' qx_typed1 `het' `LASSO1'" "'

// RI P-VALUES
	ritest qx_typed1 _b[qx_typed1], reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_typed1 `het' `LASSO1' if female==`i', absorb(ea_code) cluster(`CL')  // P-value para el coeff T1 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]
//ESTIMATION		
		foreach model of local models {
			
			reghdfe `model' if female==`i', absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

			
//OUTPUT
			outreg2 using "$tables\TableA17.xls", `append' noomitted label excel dec(3) addtext(RI pval T1, "[`ri_1']",Outcome Control Mean, `meanY') ctitle ("`outcome'")  
			local append = "append"

		}
}
}
}

**# Table A18: The Survey Methods' Effects on Employment Across Economic Sectors
local lasso1 female age high_school read_write never_married access_cellphone access_internet 
local outcomes `" "agrivsnowork" "act_agri" "agrivservi" "agrivsmanuf" "agrivscomm" "'
local CL hhid

local append = "replace"

foreach outcome of local outcomes {
			
//LASSO
		dsregress `outcome' qx_typed1 qx_typed2, controls((i.ea_code) `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"

// RI P-VALUES
		ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' i.qx_type  `LASSO1', absorb(ea_code) cluster(`CL') 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]

		ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' i.qx_type  `LASSO1', absorb(ea_code) cluster(`CL') 
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

//ESTIMATION
		reghdfe `outcome' qx_typed1 qx_typed2 `LASSO1', absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'
//OUTPUT
		outreg2 using "$tables\TableA18.xls", `append' noomitted label excel dec(3) addtext(RI pval LOA, "[`ri_1']",RI pval ESR, "[`ri_2']",Outcome Control Mean, `meanY') ctitle ("`outcome'")  
			local append = "append"
			
// LASSO			
			dsregress `outcome' qx_typed1 qx_typed2 treat1_female treat2_female, controls((i.ea_code female) `lasso1') rseed(487361) vce(cluster `CL')
			local LASSO1 "`e(controls_sel)'"
			
// RI P-VALUES
	ritest qx_type _b[1.qx_type], fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##female `LASSO1', absorb(ea_code) cluster(`CL')  // P-value para el coeff T1 
			mat p = r(p)
			local ri_1 : display %4.3f p[1,1]
			
	ritest qx_type (_b[1.qx_type#1.female]), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##female `LASSO1', absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x D
			mat p = r(p)
			local ri_2 : display %4.3f p[1,1]

	ritest qx_type (_b[1.qx_type] + _b[1.qx_type#1.female]), fixlevels(2) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##female  `LASSO1' , absorb(ea_code) cluster(`CL') // P-value para el coeff T1 x D + T1
			mat p = r(p)
			local ri_3 : display %4.3f p[1,1]

	ritest qx_type _b[2.qx_type], fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##female `LASSO1', absorb(ea_code) cluster(`CL')  // P-value para el coeff T2 
			mat p = r(p)
			local ri_4 : display %4.3f p[1,1]
			
	ritest qx_type (_b[2.qx_type#1.female]), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##female `LASSO1', absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x D
			mat p = r(p)
			local ri_5 : display %4.3f p[1,1]

	ritest qx_type (_b[2.qx_type] + _b[2.qx_type#1.female]), fixlevels(1) reps(1000) seed(487361) strata(ea_code) reseed: reghdfe `outcome' qx_type##female `LASSO1' , absorb(ea_code) cluster(`CL') // P-value para el coeff T2 x D + T2
			mat p = r(p)
			local ri_6 : display %4.3f p[1,1]

//ESTIMATION			
			reghdfe `outcome' qx_typed1 qx_typed2 female treat1_female treat2_female `LASSO1', absorb(ea_code) cluster(`CL') 
			sum `outcome' if e(sample) == 1 & control==1 //mean
			local meanY : display %4.3f `r(mean)'

				lincom qx_typed1 + treat1_female
				local sumcoef1: display %4.3f `r(estimate)'
				local secoef1:  display %4.3f `r(se)'
				local pvalue1: display %4.3f `r(p)'
				if `pvalue1'<0.1{
				local sig1 "*"
				}
				if `pvalue1'<0.05{
				local sig1 "**"
				}

				if `pvalue1'<0.01{
				local sig1 "***"
				}
				
				lincom qx_typed2 + treat2_female
				local sumcoef2: display %4.3f `r(estimate)'
				local secoef2:  display %4.3f `r(se)'
				local pvalue2: display %4.3f `r(p)'
				if `pvalue2'<0.1{
				local sig2 "*"
				}
				if `pvalue2'<0.05{
				local sig2 "**"
				}

				if `pvalue2'<0.01{
				local sig2 "***"
				}
// OUTPUT
	outreg2 using "$tables\TableA18.xls", `append' noomitted label excel dec(3) addtext(LOA + LOA x Female,`sumcoef1'`sig1',se1,"(`secoef1')", ESR + ESR x Female,`sumcoef2'`sig2', se2,"(`secoef2')",RI pval LOA, "[`ri_1']",RI pval LOA x Female, "[`ri_2']",RI pval LOA + LOA x Female , "[`ri_3']",RI pval ESR, "[`ri_4']",RI pval ESR x Female, "[`ri_5']",RI pval ESR + ESR x Female, "[`ri_6']", Outcome Control Mean, `meanY')  
			local append = "append"
			local sig1 ""
			local sig2 ""			
}


********************************************************************************

** Delete .txt files that have been created using `outreg2'
cd "$tables"
shell erase *.txt
