/*******************************************************************************
*                           MASTER DO-FILE  		                           *
********************************************************************************
*                                                                              *
*   PURPOSE:     Reproduce all data work, map inputs and outputs,              *
*                facilitate collaboration                                      *
*                                                                              *
*   OUTLINE:     PART 1:  Set standard settings and install packages           *
*                PART 2:  Prepare folder paths and define programs             *
*                PART 3:  Run do-files                                         *
*                                                                              *
********************************************************************************
    PART 1:  Install user-written packages and harmonize settings
********************************************************************************/
/*
    local user_commands outreg2 ereplace reghdfe balancetable swindex coefplot ftools
    foreach command of local user_commands {
        cap which `command'
        if _rc == 111 ssc install `command'
    }
	
	net describe ritest, from(https://raw.githubusercontent.com/simonheb/ritest/master/)
	net install ritest, replace
*/

/*******************************************************************************
    PART 2:  Prepare folder paths and define programs
*******************************************************************************/
    * Folder paths
	global base "../"	
	
	* Do files
	global dofiles "${base}/Do files"
	sysdir set PLUS "${dofiles}/ado"
	* Raw data
	global raw "${base}/Data anonymized/Raw data"
	* Intermediate files	
	global intermed "${base}/Data anonymized/Intermediate data" 	
	* Clean data
	global baseclean "${base}/Data anonymized/Clean data"
	*Output
	global output "${base}/Output"
	global tables "${output}/Tables"
	global figures "${output}/Figures"


/*******************************************************************************
    PART 3: Run do-files
*******************************************************************************/

/*-----------------------------------------------------------------------------
    PART 3.1:  Construct variables and indicators
    REQUIRES:   "$intermed\all_sections.dta"
    CREATES:    "$baseclean\master_data.dta"
    IDS VAR:    hhid r_members__id
----------------------------------------------------------------------------- */
    *Change the 0 to 1 to run the variable construction do-file
    if (1) do "$dofiles/01_variables_creation.do"
	
/*-----------------------------------------------------------------------------
    PART 3.2:  Construct a dataset with EHPM to compare
    REQUIRES:   "$raw\EHPM 2022.sav"
    CREATES:    "$intermed\EHPM 2022_restringida.dta"
----------------------------------------------------------------------------- */
 /*
	To execute this code, you must first download the dataset "Encuesta de Hogares de Propósitos Multiples 2022" by following these instructions:

	1. Navigate to the public repository by visiting the following link in your web browser: [https://onec.bcr.gob.sv/Repositorio_archivos/]
	2. Fill in the required fields to register. Once completed, datasets available for download, along with their respective years, will appear on the right side of the webpage.
	3. Locate the "Encuesta de Hogares de Propósitos Multiples 2022" and click on the green download button next to its name.
	4. Extract the compressed/zipped folder and save the downloaded dataset in the "Raw data" folder within the replication package directory.
	5. Finally, run the code.
*/

	*Change the 0 to 1 to run the ehpm construction do-file
    if (1) do "$dofiles/02_ehpm.do"

/*-----------------------------------------------------------------------------
    PART 3.3:  Run the main tables and figures do-file
    REQUIRES:   "$intermed\master_data.dta"
    CREATES:    
    IDS VAR:    hhid r_members__id
----------------------------------------------------------------------------- */
    *Change the 0 to 1 to run the main analysis do-file
    if (1) do "$dofiles/03_main_tables_figures.do"

/*-----------------------------------------------------------------------------
    PART 3.4:  Run the appendix tables and figures do-file
    REQUIRES:   "$intermed\master_data.dta"
    CREATES:    
    IDS VAR:    hhid r_members__id
----------------------------------------------------------------------------- */
    *Change the 0 to 1 to run the main analysis do-file
    if (1) do "$dofiles/04_appendix_tables.do"

***************************************************************** End of do-file
